'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var iconsMaterial = require('@mui/icons-material');
var reactTable = require('@tanstack/react-table');
var material = require('@mui/material');
var matchSorterUtils = require('@tanstack/match-sorter-utils');
var reactVirtual = require('@tanstack/react-virtual');

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MRT_DefaultLocalization_EN = {
  actions: 'Actions',
  and: 'and',
  cancel: 'Cancel',
  changeFilterMode: 'Change filter mode',
  changeSearchMode: 'Change search mode',
  clearFilter: 'Clear filter',
  clearSearch: 'Clear search',
  clearSort: 'Clear sort',
  clickToCopy: 'Click to copy',
  columnActions: 'Column Actions',
  copiedToClipboard: 'Copied to clipboard',
  edit: 'Edit',
  expand: 'Expand',
  expandAll: 'Expand all',
  filterArrIncludes: 'Includes',
  filterArrIncludesAll: 'Includes all',
  filterArrIncludesSome: 'Includes',
  filterBetween: 'Between',
  filterBetweenInclusive: 'Between Inclusive',
  filterByColumn: 'Filter by {column}',
  filterContains: 'Contains',
  filterEmpty: 'Empty',
  filterEndsWith: 'Ends With',
  filterEquals: 'Equals',
  filterEqualsString: 'Equals',
  filterFuzzy: 'Fuzzy',
  filterGreaterThan: 'Greater Than',
  filterGreaterThanOrEqualTo: 'Greater Than Or Equal To',
  filterInNumberRange: 'Between',
  filterIncludesString: 'Contains',
  filterIncludesStringSensitive: 'Contains',
  filterLessThan: 'Less Than',
  filterLessThanOrEqualTo: 'Less Than Or Equal To',
  filterMode: 'Filter Mode: {filterType}',
  filterNotEmpty: 'Not Empty',
  filterNotEquals: 'Not Equals',
  filterStartsWith: 'Starts With',
  filterWeakEquals: 'Equals',
  filteringByColumn: 'Filtering by {column} - {filterType} {filterValue}',
  grab: 'Grab',
  groupByColumn: 'Group by {column}',
  groupedBy: 'Grouped by ',
  hideAll: 'Hide all',
  hideColumn: 'Hide {column} column',
  max: 'Max',
  min: 'Min',
  move: 'Move',
  or: 'or',
  pinToLeft: 'Pin to left',
  pinToRight: 'Pin to right',
  resetColumnSize: 'Reset column size',
  resetOrder: 'Reset order',
  rowActions: 'Row Actions',
  rowNumber: '#',
  rowNumbers: 'Row Numbers',
  save: 'Save',
  search: 'Search',
  selectedCountOfRowCountRowsSelected: '{selectedCount} of {rowCount} row(s) selected',
  select: 'Select',
  showAll: 'Show all',
  showAllColumns: 'Show all columns',
  showHideColumns: 'Show/Hide columns',
  showHideFilters: 'Show/Hide filters',
  showHideSearch: 'Show/Hide search',
  sortByColumnAsc: 'Sort by {column} ascending',
  sortByColumnDesc: 'Sort by {column} descending',
  sortedByColumnAsc: 'Sorted by {column} ascending',
  sortedByColumnDesc: 'Sorted by {column} descending',
  thenBy: ', then by ',
  toggleDensity: 'Toggle density',
  toggleFullScreen: 'Toggle full screen',
  toggleSelectAll: 'Toggle select all',
  toggleSelectRow: 'Toggle select row',
  toggleVisibility: 'Toggle visibility',
  ungroupByColumn: 'Ungroup by {column}',
  unpin: 'Unpin',
  unpinAll: 'Unpin all',
  unsorted: 'Unsorted'
};

var MRT_Default_Icons = {
  ArrowRightIcon: iconsMaterial.ArrowRight,
  CancelIcon: iconsMaterial.Cancel,
  CheckBoxIcon: iconsMaterial.CheckBox,
  ClearAllIcon: iconsMaterial.ClearAll,
  CloseIcon: iconsMaterial.Close,
  DensityLargeIcon: iconsMaterial.DensityLarge,
  DensityMediumIcon: iconsMaterial.DensityMedium,
  DensitySmallIcon: iconsMaterial.DensitySmall,
  DragHandleIcon: iconsMaterial.DragHandle,
  DynamicFeedIcon: iconsMaterial.DynamicFeed,
  EditIcon: iconsMaterial.Edit,
  ExpandLessIcon: iconsMaterial.ExpandLess,
  ExpandMoreIcon: iconsMaterial.ExpandMore,
  FilterAltIcon: iconsMaterial.FilterAlt,
  FilterAltOffIcon: iconsMaterial.FilterAltOff,
  FilterListIcon: iconsMaterial.FilterList,
  FilterListOffIcon: iconsMaterial.FilterListOff,
  FullscreenExitIcon: iconsMaterial.FullscreenExit,
  FullscreenIcon: iconsMaterial.Fullscreen,
  KeyboardDoubleArrowDownIcon: iconsMaterial.KeyboardDoubleArrowDown,
  MoreHorizIcon: iconsMaterial.MoreHoriz,
  MoreVertIcon: iconsMaterial.MoreVert,
  PushPinIcon: iconsMaterial.PushPin,
  RestartAltIcon: iconsMaterial.RestartAlt,
  SaveIcon: iconsMaterial.Save,
  SearchIcon: iconsMaterial.Search,
  SearchOffIcon: iconsMaterial.SearchOff,
  SortIcon: iconsMaterial.Sort,
  ViewColumnIcon: iconsMaterial.ViewColumn,
  VisibilityOffIcon: iconsMaterial.VisibilityOff
};

var MRT_ExpandAllButton = function MRT_ExpandAllButton(_ref) {
  var table = _ref.table;
  var getIsAllRowsExpanded = table.getIsAllRowsExpanded,
      getIsSomeRowsExpanded = table.getIsSomeRowsExpanded,
      getCanSomeRowsExpand = table.getCanSomeRowsExpand,
      getState = table.getState,
      _table$options = table.options,
      KeyboardDoubleArrowDownIcon = _table$options.icons.KeyboardDoubleArrowDownIcon,
      localization = _table$options.localization,
      muiExpandAllButtonProps = _table$options.muiExpandAllButtonProps,
      renderDetailPanel = _table$options.renderDetailPanel,
      toggleAllRowsExpanded = table.toggleAllRowsExpanded;

  var _getState = getState(),
      density = _getState.density;

  var iconButtonProps = muiExpandAllButtonProps instanceof Function ? muiExpandAllButtonProps({
    table: table
  }) : muiExpandAllButtonProps;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expandAll
  }, React__default.createElement("span", null, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.expandAll,
    disabled: !getCanSomeRowsExpand() && !renderDetailPanel,
    onClick: function onClick() {
      return toggleAllRowsExpanded(!getIsAllRowsExpanded());
    }
  }, iconButtonProps, {
    sx: _extends({
      height: density === 'compact' ? '1.75rem' : '2.25rem',
      width: density === 'compact' ? '1.75rem' : '2.25rem',
      mt: density !== 'compact' ? '-0.25rem' : undefined
    }, iconButtonProps == null ? void 0 : iconButtonProps.sx)
  }), React__default.createElement(KeyboardDoubleArrowDownIcon, {
    style: {
      transform: "rotate(" + (getIsAllRowsExpanded() ? -180 : getIsSomeRowsExpanded() ? -90 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  }))));
};

var MRT_ExpandButton = function MRT_ExpandButton(_ref) {
  var row = _ref.row,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      ExpandMoreIcon = _table$options.icons.ExpandMoreIcon,
      localization = _table$options.localization,
      muiExpandButtonProps = _table$options.muiExpandButtonProps,
      renderDetailPanel = _table$options.renderDetailPanel;

  var _getState = getState(),
      density = _getState.density;

  var iconButtonProps = muiExpandButtonProps instanceof Function ? muiExpandButtonProps({
    table: table,
    row: row
  }) : muiExpandButtonProps;

  var handleToggleExpand = function handleToggleExpand() {
    row.toggleExpanded();
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.expand
  }, React__default.createElement("span", null, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.expand,
    disabled: !row.getCanExpand() && !renderDetailPanel,
    onClick: handleToggleExpand
  }, iconButtonProps, {
    sx: function sx(theme) {
      return _extends({
        height: density === 'compact' ? '1.75rem' : '2.25rem',
        width: density === 'compact' ? '1.75rem' : '2.25rem'
      }, (iconButtonProps == null ? void 0 : iconButtonProps.sx) instanceof Function ? iconButtonProps.sx(theme) : iconButtonProps == null ? void 0 : iconButtonProps.sx);
    }
  }), React__default.createElement(ExpandMoreIcon, {
    style: {
      transform: "rotate(" + (!row.getCanExpand() && !renderDetailPanel ? -90 : row.getIsExpanded() ? -180 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  }))));
};

var internalFilterOptions = function internalFilterOptions(localization) {
  return [{
    option: 'fuzzy',
    symbol: '≈',
    label: localization.filterFuzzy,
    divider: false
  }, {
    option: 'contains',
    symbol: '*',
    label: localization.filterContains,
    divider: false
  }, {
    option: 'startsWith',
    symbol: 'a',
    label: localization.filterStartsWith,
    divider: false
  }, {
    option: 'endsWith',
    symbol: 'z',
    label: localization.filterEndsWith,
    divider: true
  }, {
    option: 'equals',
    symbol: '=',
    label: localization.filterEquals,
    divider: false
  }, {
    option: 'notEquals',
    symbol: '≠',
    label: localization.filterNotEquals,
    divider: true
  }, {
    option: 'between',
    symbol: '⇿',
    label: localization.filterBetween,
    divider: false
  }, {
    option: 'betweenInclusive',
    symbol: '⬌',
    label: localization.filterBetweenInclusive,
    divider: true
  }, {
    option: 'greaterThan',
    symbol: '>',
    label: localization.filterGreaterThan,
    divider: false
  }, {
    option: 'greaterThanOrEqualTo',
    symbol: '≥',
    label: localization.filterGreaterThanOrEqualTo,
    divider: false
  }, {
    option: 'lessThan',
    symbol: '<',
    label: localization.filterLessThan,
    divider: false
  }, {
    option: 'lessThanOrEqualTo',
    symbol: '≤',
    label: localization.filterLessThanOrEqualTo,
    divider: true
  }, {
    option: 'empty',
    symbol: '∅',
    label: localization.filterEmpty,
    divider: false
  }, {
    option: 'notEmpty',
    symbol: '!∅',
    label: localization.filterNotEmpty,
    divider: false
  }];
};
var MRT_FilterOptionMenu = function MRT_FilterOptionMenu(_ref) {
  var _columnDef$columnFilt;

  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      onSelect = _ref.onSelect,
      setAnchorEl = _ref.setAnchorEl,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enabledGlobalFilterOptions = _table$options.enabledGlobalFilterOptions,
      columnFilterModeOptions = _table$options.columnFilterModeOptions,
      localization = _table$options.localization,
      setCurrentFilterFns = table.setCurrentFilterFns,
      setCurrentGlobalFilterFn = table.setCurrentGlobalFilterFn;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns,
      currentGlobalFilterFn = _getState.currentGlobalFilterFn,
      density = _getState.density;

  var _ref2 = header != null ? header : {},
      column = _ref2.column;

  var _ref3 = column != null ? column : {},
      columnDef = _ref3.columnDef;

  var allowedColumnFilterOptions = (_columnDef$columnFilt = columnDef == null ? void 0 : columnDef.columnFilterModeOptions) != null ? _columnDef$columnFilt : columnFilterModeOptions;
  var filterOptions = React.useMemo(function () {
    return internalFilterOptions(localization).filter(function (filterOption) {
      return columnDef ? allowedColumnFilterOptions === undefined || (allowedColumnFilterOptions == null ? void 0 : allowedColumnFilterOptions.includes(filterOption.option)) : (!enabledGlobalFilterOptions || enabledGlobalFilterOptions.includes(filterOption.option)) && ['fuzzy', 'contains'].includes(filterOption.option);
    });
  }, []);

  var handleSelectFilterType = function handleSelectFilterType(option) {
    if (header && column) {
      setCurrentFilterFns(function (prev) {
        var _extends2;

        return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = option, _extends2));
      });

      if (['empty', 'notEmpty'].includes(option)) {
        column.setFilterValue(' ');
      } else if (option === 'between') {
        column.setFilterValue(['', '']);
      } else {
        column.setFilterValue('');
      }
    } else {
      setCurrentGlobalFilterFn(option);
    }

    setAnchorEl(null);
    onSelect == null ? void 0 : onSelect();
  };

  var filterOption = !!header ? currentFilterFns[header.id] : currentGlobalFilterFn;
  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    anchorOrigin: {
      vertical: 'center',
      horizontal: 'right'
    },
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    open: !!anchorEl,
    MenuListProps: {
      dense: density === 'compact'
    }
  }, filterOptions.map(function (_ref4, index) {
    var option = _ref4.option,
        label = _ref4.label,
        divider = _ref4.divider,
        symbol = _ref4.symbol;
    return React__default.createElement(material.MenuItem, {
      divider: divider,
      key: index,
      onClick: function onClick() {
        return handleSelectFilterType(option);
      },
      selected: option === filterOption,
      sx: {
        py: '6px',
        my: 0,
        alignItems: 'center',
        display: 'flex',
        gap: '2ch'
      },
      value: option
    }, React__default.createElement(material.Box, {
      sx: {
        fontSize: '1.25rem',
        width: '2ch'
      }
    }, symbol), label);
  }));
};

var MRT_ColumnPinningButtons = function MRT_ColumnPinningButtons(_ref) {
  var column = _ref.column,
      table = _ref.table;
  var _table$options = table.options,
      PushPinIcon = _table$options.icons.PushPinIcon,
      localization = _table$options.localization;

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
  };

  return React__default.createElement(material.Box, {
    sx: {
      minWidth: '70px',
      textAlign: 'center'
    }
  }, column.getIsPinned() ? React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.unpin
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, null))) : React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.pinToLeft
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  }))), React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.pinToRight
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    size: "small"
  }, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })))));
};

var MRT_GrabHandleButton = function MRT_GrabHandleButton(_ref) {
  var iconButtonProps = _ref.iconButtonProps,
      onDragEnd = _ref.onDragEnd,
      onDragStart = _ref.onDragStart,
      table = _ref.table;
  var _table$options = table.options,
      DragHandleIcon = _table$options.icons.DragHandleIcon,
      localization = _table$options.localization;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.move
  }, React__default.createElement(material.IconButton, Object.assign({
    disableRipple: true,
    draggable: "true",
    onDragStart: onDragStart,
    onDragEnd: onDragEnd,
    size: "small"
  }, iconButtonProps, {
    sx: _extends({
      cursor: 'grab',
      m: 0,
      opacity: 0.5,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 1
      },
      '&:active': {
        cursor: 'grabbing'
      }
    }, iconButtonProps == null ? void 0 : iconButtonProps.sx)
  }), React__default.createElement(DragHandleIcon, null)));
};

var fuzzy = function fuzzy(row, columnId, filterValue, addMeta) {
  var itemRank = matchSorterUtils.rankItem(row.getValue(columnId), filterValue, {
    threshold: matchSorterUtils.rankings.MATCHES
  });
  addMeta(itemRank);
  return itemRank.passed;
};

fuzzy.autoRemove = function (val) {
  return !val;
};

var contains = function contains(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().includes(filterValue.toString().toLowerCase().trim());
};

contains.autoRemove = function (val) {
  return !val;
};

var startsWith = function startsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().startsWith(filterValue.toString().toLowerCase().trim());
};

startsWith.autoRemove = function (val) {
  return !val;
};

var endsWith = function endsWith(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim().endsWith(filterValue.toString().toLowerCase().trim());
};

endsWith.autoRemove = function (val) {
  return !val;
};

var equals = function equals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() === filterValue.toString().toLowerCase().trim();
};

equals.autoRemove = function (val) {
  return !val;
};

var notEquals = function notEquals(row, id, filterValue) {
  return row.getValue(id).toString().toLowerCase().trim() !== filterValue.toString().toLowerCase().trim();
};

notEquals.autoRemove = function (val) {
  return !val;
};

var greaterThan = function greaterThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) > +filterValue : row.getValue(id).toString().toLowerCase().trim() > filterValue.toString().toLowerCase().trim();
};

greaterThan.autoRemove = function (val) {
  return !val;
};

var greaterThanOrEqualTo = function greaterThanOrEqualTo(row, id, filterValue) {
  return equals(row, id, filterValue) || greaterThan(row, id, filterValue);
};

greaterThanOrEqualTo.autoRemove = function (val) {
  return !val;
};

var lessThan = function lessThan(row, id, filterValue) {
  return !isNaN(+filterValue) && !isNaN(+row.getValue(id)) ? +row.getValue(id) < +filterValue : row.getValue(id).toString().toLowerCase().trim() < filterValue.toString().toLowerCase().trim();
};

lessThan.autoRemove = function (val) {
  return !val;
};

var lessThanOrEqualTo = function lessThanOrEqualTo(row, id, filterValue) {
  return equals(row, id, filterValue) || lessThan(row, id, filterValue);
};

lessThanOrEqualTo.autoRemove = function (val) {
  return !val;
};

var between = function between(row, id, filterValues) {
  return (['', undefined].includes(filterValues[0]) || greaterThan(row, id, filterValues[0])) && (!isNaN(+filterValues[0]) && !isNaN(+filterValues[1]) && +filterValues[0] > +filterValues[1] || ['', undefined].includes(filterValues[1]) || lessThan(row, id, filterValues[1]));
};

between.autoRemove = function (val) {
  return !val;
};

var betweenInclusive = function betweenInclusive(row, id, filterValues) {
  return (['', undefined].includes(filterValues[0]) || greaterThanOrEqualTo(row, id, filterValues[0])) && (!isNaN(+filterValues[0]) && !isNaN(+filterValues[1]) && +filterValues[0] > +filterValues[1] || ['', undefined].includes(filterValues[1]) || lessThanOrEqualTo(row, id, filterValues[1]));
};

betweenInclusive.autoRemove = function (val) {
  return !val;
};

var empty = function empty(row, id, _filterValue) {
  return !row.getValue(id).toString().trim();
};

empty.autoRemove = function (val) {
  return !val;
};

var notEmpty = function notEmpty(row, id, _filterValue) {
  return !!row.getValue(id).toString().trim();
};

notEmpty.autoRemove = function (val) {
  return !val;
};

var MRT_FilterFns = /*#__PURE__*/_extends({}, reactTable.filterFns, {
  between: between,
  betweenInclusive: betweenInclusive,
  contains: contains,
  empty: empty,
  endsWith: endsWith,
  equals: equals,
  fuzzy: fuzzy,
  greaterThan: greaterThan,
  greaterThanOrEqualTo: greaterThanOrEqualTo,
  lessThan: lessThan,
  lessThanOrEqualTo: lessThanOrEqualTo,
  notEmpty: notEmpty,
  notEquals: notEquals,
  startsWith: startsWith
});

var fuzzy$1 = function fuzzy(rowA, rowB, columnId) {
  var dir = 0;

  if (rowA.columnFiltersMeta[columnId]) {
    dir = matchSorterUtils.compareItems(rowA.columnFiltersMeta[columnId], rowB.columnFiltersMeta[columnId]);
  } // Provide a fallback for when the item ranks are equal


  return dir === 0 ? reactTable.sortingFns.alphanumeric(rowA, rowB, columnId) : dir;
};

var MRT_SortingFns = /*#__PURE__*/_extends({}, reactTable.sortingFns, {
  fuzzy: fuzzy$1
});
var rankGlobalFuzzy = function rankGlobalFuzzy(rowA, rowB) {
  return Math.max.apply(Math, Object.values(rowB.columnFiltersMeta).map(function (v) {
    return v.rank;
  })) - Math.max.apply(Math, Object.values(rowA.columnFiltersMeta).map(function (v) {
    return v.rank;
  }));
};

var getColumnId = function getColumnId(columnDef) {
  var _ref, _columnDef$id, _columnDef$accessorKe;

  return (_ref = (_columnDef$id = columnDef.id) != null ? _columnDef$id : (_columnDef$accessorKe = columnDef.accessorKey) == null ? void 0 : _columnDef$accessorKe.toString == null ? void 0 : _columnDef$accessorKe.toString()) != null ? _ref : columnDef.header;
};

var getAllLeafColumnDefs = function getAllLeafColumnDefs(columns) {
  var lowestLevelColumns = columns;
  var currentCols = columns;

  while (!!((_currentCols = currentCols) != null && _currentCols.length) && currentCols.some(function (col) {
    return col.columns;
  })) {
    var _currentCols;

    var nextCols = currentCols.filter(function (col) {
      return !!col.columns;
    }).map(function (col) {
      return col.columns;
    }).flat();

    if (nextCols.every(function (col) {
      return !(col != null && col.columns);
    })) {
      lowestLevelColumns = [].concat(lowestLevelColumns, nextCols);
    }

    currentCols = nextCols;
  }

  return lowestLevelColumns.filter(function (col) {
    return !col.columns;
  });
};
var prepareColumns = function prepareColumns(columnDefs, currentFilterFns) {
  return columnDefs.map(function (columnDef) {
    var _columnDef$columns;

    if (!columnDef.id) columnDef.id = getColumnId(columnDef);

    if ( !columnDef.id) {
      console.error('Column definitions must have a valid `accessorKey` or `id` property');
    }

    if (!columnDef.columnDefType) columnDef.columnDefType = 'data';

    if (!!((_columnDef$columns = columnDef.columns) != null && _columnDef$columns.length)) {
      columnDef.columnDefType = 'group';
      columnDef.columns = prepareColumns(columnDef.columns, currentFilterFns);
    } else if (columnDef.columnDefType === 'data') {
      if (Object.keys(MRT_FilterFns).includes(currentFilterFns[columnDef.id])) {
        var _MRT_FilterFns$curren;

        columnDef.filterFn = (_MRT_FilterFns$curren = MRT_FilterFns[currentFilterFns[columnDef.id]]) != null ? _MRT_FilterFns$curren : MRT_FilterFns.fuzzy; //@ts-ignore

        columnDef._filterFn = currentFilterFns[columnDef.id];
      }

      if (Object.keys(MRT_SortingFns).includes(columnDef.sortingFn)) {
        // @ts-ignore
        columnDef.sortingFn = MRT_SortingFns[columnDef.sortingFn];
      }
    }

    return columnDef;
  });
};
var reorderColumn = function reorderColumn(draggedColumn, targetColumn, columnOrder) {
  if (draggedColumn.getCanPin()) {
    draggedColumn.pin(targetColumn.getIsPinned());
  }

  columnOrder.splice(columnOrder.indexOf(targetColumn.id), 0, columnOrder.splice(columnOrder.indexOf(draggedColumn.id), 1)[0]);
  return [].concat(columnOrder);
};
var getLeadingDisplayColumnIds = function getLeadingDisplayColumnIds(props) {
  return [(props.enableRowDragging || props.enableRowOrdering) && 'mrt-row-drag', (props.positionActionsColumn === 'first' && props.enableRowActions || props.enableEditing && props.editingMode === 'row') && 'mrt-row-actions', props.positionExpandColumn === 'first' && (props.enableExpanding || props.enableGrouping || props.renderDetailPanel) && 'mrt-row-expand', props.enableRowSelection && 'mrt-row-select', props.enableRowNumbers && 'mrt-row-numbers'].filter(Boolean);
};
var getTrailingDisplayColumnIds = function getTrailingDisplayColumnIds(props) {
  return [(props.positionActionsColumn === 'last' && props.enableRowActions || props.enableEditing && props.editingMode === 'row') && 'mrt-row-actions', props.positionExpandColumn === 'last' && (props.enableExpanding || props.enableGrouping || props.renderDetailPanel) && 'mrt-row-expand'];
};
var getDefaultColumnOrderIds = function getDefaultColumnOrderIds(props) {
  return [].concat(getLeadingDisplayColumnIds(props), getAllLeafColumnDefs(props.columns).map(function (columnDef) {
    return getColumnId(columnDef);
  }), getTrailingDisplayColumnIds(props)).filter(Boolean);
};
var getDefaultColumnFilterFn = function getDefaultColumnFilterFn(columnDef) {
  if (columnDef.filterVariant === 'multi-select') return 'arrIncludesSome';
  if (columnDef.filterVariant === 'select') return 'equals';
  if (columnDef.filterVariant === 'range') return 'betweenInclusive';
  return 'fuzzy';
};

var MRT_ShowHideColumnsMenuItems = function MRT_ShowHideColumnsMenuItems(_ref) {
  var _column$columns2;

  var allColumns = _ref.allColumns,
      currentHoveredColumn = _ref.currentHoveredColumn,
      setCurrentHoveredColumn = _ref.setCurrentHoveredColumn,
      column = _ref.column,
      isSubMenu = _ref.isSubMenu,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableColumnOrdering = _table$options.enableColumnOrdering,
      enableHiding = _table$options.enableHiding,
      enablePinning = _table$options.enablePinning,
      localization = _table$options.localization,
      setColumnOrder = table.setColumnOrder;

  var _getState = getState(),
      columnOrder = _getState.columnOrder;

  var columnDef = column.columnDef;
  var columnDefType = columnDef.columnDefType;
  var switchChecked = columnDefType !== 'group' && column.getIsVisible() || columnDefType === 'group' && column.getLeafColumns().some(function (col) {
    return col.getIsVisible();
  });

  var handleToggleColumnHidden = function handleToggleColumnHidden(column) {
    if (columnDefType === 'group') {
      var _column$columns;

      column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.forEach == null ? void 0 : _column$columns.forEach(function (childColumn) {
        childColumn.toggleVisibility(!switchChecked);
      });
    } else {
      column.toggleVisibility();
    }
  };

  var menuItemRef = React__default.useRef(null);

  var _useState = React.useState(false),
      isDragging = _useState[0],
      setIsDragging = _useState[1];

  var handleDragStart = function handleDragStart(e) {
    setIsDragging(true);
    e.dataTransfer.setDragImage(menuItemRef.current, 0, 0);
  };

  var handleDragEnd = function handleDragEnd(_e) {
    setIsDragging(false);
    setCurrentHoveredColumn(null);

    if (currentHoveredColumn) {
      setColumnOrder(reorderColumn(column, currentHoveredColumn, columnOrder));
    }
  };

  var handleDragEnter = function handleDragEnter(_e) {
    if (!isDragging) {
      setCurrentHoveredColumn(column);
    }
  };

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.MenuItem, {
    disableRipple: true,
    ref: menuItemRef,
    onDragEnter: handleDragEnter,
    sx: function sx(theme) {
      return {
        alignItems: 'center',
        justifyContent: 'flex-start',
        my: 0,
        opacity: isDragging ? 0.5 : 1,
        outline: isDragging ? "1px dashed " + theme.palette.divider : (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) === column.id ? "2px dashed " + theme.palette.primary.main : 'none',
        pl: (column.depth + 0.5) * 2 + "rem",
        py: '6px'
      };
    }
  }, React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      flexWrap: 'nowrap',
      gap: '8px'
    }
  }, !isSubMenu && columnDefType !== 'group' && enableColumnOrdering && !allColumns.some(function (col) {
    return col.columnDef.columnDefType === 'group';
  }) && (columnDef.enableColumnOrdering !== false ? React__default.createElement(MRT_GrabHandleButton, {
    onDragEnd: handleDragEnd,
    onDragStart: handleDragStart,
    table: table
  }) : React__default.createElement(material.Box, {
    sx: {
      width: '28px'
    }
  })), !isSubMenu && enablePinning && (column.getCanPin() ? React__default.createElement(MRT_ColumnPinningButtons, {
    column: column,
    table: table
  }) : React__default.createElement(material.Box, {
    sx: {
      width: '70px'
    }
  })), enableHiding ? React__default.createElement(material.FormControlLabel, {
    componentsProps: {
      typography: {
        sx: {
          mb: 0,
          opacity: columnDefType !== 'display' ? 1 : 0.5
        }
      }
    },
    checked: switchChecked,
    control: React__default.createElement(material.Tooltip, {
      arrow: true,
      enterDelay: 1000,
      enterNextDelay: 1000,
      title: localization.toggleVisibility
    }, React__default.createElement(material.Switch, null)),
    disabled: isSubMenu && switchChecked || !column.getCanHide() || column.getIsGrouped(),
    label: columnDef.header,
    onChange: function onChange() {
      return handleToggleColumnHidden(column);
    }
  }) : React__default.createElement(material.Typography, {
    sx: {
      alignSelf: 'center'
    }
  }, columnDef.header))), (_column$columns2 = column.columns) == null ? void 0 : _column$columns2.map(function (c, i) {
    return React__default.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      column: c,
      currentHoveredColumn: currentHoveredColumn,
      isSubMenu: isSubMenu,
      key: i + "-" + c.id,
      setCurrentHoveredColumn: setCurrentHoveredColumn,
      table: table
    });
  }));
};

var MRT_ShowHideColumnsMenu = function MRT_ShowHideColumnsMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      isSubMenu = _ref.isSubMenu,
      setAnchorEl = _ref.setAnchorEl,
      table = _ref.table;
  var getAllColumns = table.getAllColumns,
      getAllLeafColumns = table.getAllLeafColumns,
      getCenterLeafColumns = table.getCenterLeafColumns,
      getIsAllColumnsVisible = table.getIsAllColumnsVisible,
      getIsSomeColumnsPinned = table.getIsSomeColumnsPinned,
      getIsSomeColumnsVisible = table.getIsSomeColumnsVisible,
      getLeftLeafColumns = table.getLeftLeafColumns,
      getRightLeafColumns = table.getRightLeafColumns,
      getState = table.getState,
      toggleAllColumnsVisible = table.toggleAllColumnsVisible,
      _table$options = table.options,
      localization = _table$options.localization,
      enablePinning = _table$options.enablePinning,
      enableColumnOrdering = _table$options.enableColumnOrdering;

  var _getState = getState(),
      density = _getState.density,
      columnOrder = _getState.columnOrder,
      columnPinning = _getState.columnPinning;

  var hideAllColumns = function hideAllColumns() {
    getAllLeafColumns().filter(function (col) {
      return col.columnDef.enableHiding !== false;
    }).forEach(function (col) {
      return col.toggleVisibility(false);
    });
  };

  var allColumns = React.useMemo(function () {
    var columns = getAllColumns();

    if (columnOrder.length > 0 && !columns.some(function (col) {
      return col.columnDef.columnDefType === 'group';
    })) {
      return [].concat(getLeftLeafColumns(), Array.from(new Set(columnOrder)).map(function (colId) {
        return getCenterLeafColumns().find(function (col) {
          return (col == null ? void 0 : col.id) === colId;
        });
      }), getRightLeafColumns()).filter(Boolean);
    }

    return columns;
  }, [columnOrder, columnPinning, getAllColumns(), getCenterLeafColumns(), getLeftLeafColumns(), getRightLeafColumns()]);

  var _useState = React.useState(null),
      currentHoveredColumn = _useState[0],
      setCurrentHoveredColumn = _useState[1];

  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: density === 'compact'
    }
  }, React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: isSubMenu ? 'center' : 'space-between',
      p: '0.5rem',
      pt: 0
    }
  }, !isSubMenu && React__default.createElement(material.Button, {
    disabled: !getIsSomeColumnsVisible(),
    onClick: hideAllColumns
  }, localization.hideAll), !isSubMenu && enableColumnOrdering && React__default.createElement(material.Button, {
    onClick: function onClick() {
      return table.setColumnOrder(getDefaultColumnOrderIds(table.options));
    }
  }, localization.resetOrder), !isSubMenu && enablePinning && React__default.createElement(material.Button, {
    disabled: !getIsSomeColumnsPinned(),
    onClick: function onClick() {
      return table.resetColumnPinning(true);
    }
  }, localization.unpinAll), React__default.createElement(material.Button, {
    disabled: getIsAllColumnsVisible(),
    onClick: function onClick() {
      return toggleAllColumnsVisible(true);
    }
  }, localization.showAll)), React__default.createElement(material.Divider, null), allColumns.map(function (column, index) {
    return React__default.createElement(MRT_ShowHideColumnsMenuItems, {
      allColumns: allColumns,
      column: column,
      currentHoveredColumn: currentHoveredColumn,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id,
      setCurrentHoveredColumn: setCurrentHoveredColumn,
      table: table
    });
  }));
};

var commonMenuItemStyles = {
  py: '6px',
  my: 0,
  justifyContent: 'space-between',
  alignItems: 'center'
};
var commonListItemStyles = {
  display: 'flex',
  alignItems: 'center'
};
var MRT_ColumnActionMenu = function MRT_ColumnActionMenu(_ref) {
  var _columnDef$columnFilt, _localization$sortByC, _localization$sortByC2, _localization$filterB, _localization, _localization$hideCol, _localization$showAll;

  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      setAnchorEl = _ref.setAnchorEl,
      table = _ref.table;
  var getState = table.getState,
      toggleAllColumnsVisible = table.toggleAllColumnsVisible,
      setColumnOrder = table.setColumnOrder,
      _table$options = table.options,
      enableColumnFilterChangeMode = _table$options.enableColumnFilterChangeMode,
      enableColumnFilters = _table$options.enableColumnFilters,
      enableColumnResizing = _table$options.enableColumnResizing,
      enableGrouping = _table$options.enableGrouping,
      enableHiding = _table$options.enableHiding,
      enablePinning = _table$options.enablePinning,
      enableSorting = _table$options.enableSorting,
      columnFilterModeOptions = _table$options.columnFilterModeOptions,
      _table$options$icons = _table$options.icons,
      ArrowRightIcon = _table$options$icons.ArrowRightIcon,
      ClearAllIcon = _table$options$icons.ClearAllIcon,
      ViewColumnIcon = _table$options$icons.ViewColumnIcon,
      DynamicFeedIcon = _table$options$icons.DynamicFeedIcon,
      FilterListIcon = _table$options$icons.FilterListIcon,
      FilterListOffIcon = _table$options$icons.FilterListOffIcon,
      PushPinIcon = _table$options$icons.PushPinIcon,
      SortIcon = _table$options$icons.SortIcon,
      RestartAltIcon = _table$options$icons.RestartAltIcon,
      VisibilityOffIcon = _table$options$icons.VisibilityOffIcon,
      tableId = _table$options.tableId,
      localization = _table$options.localization,
      setShowFilters = table.setShowFilters;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      columnSizing = _getState.columnSizing,
      columnVisibility = _getState.columnVisibility,
      density = _getState.density;

  var _useState = React.useState(null),
      filterMenuAnchorEl = _useState[0],
      setFilterMenuAnchorEl = _useState[1];

  var _useState2 = React.useState(null),
      showHideColumnsMenuAnchorEl = _useState2[0],
      setShowHideColumnsMenuAnchorEl = _useState2[1];

  var handleClearSort = function handleClearSort() {
    column.clearSorting();
    setAnchorEl(null);
  };

  var handleSortAsc = function handleSortAsc() {
    column.toggleSorting(false);
    setAnchorEl(null);
  };

  var handleSortDesc = function handleSortDesc() {
    column.toggleSorting(true);
    setAnchorEl(null);
  };

  var handleResetColumnSize = function handleResetColumnSize() {
    column.resetSize();
    setAnchorEl(null);
  };

  var handleHideColumn = function handleHideColumn() {
    column.toggleVisibility(false);
    setAnchorEl(null);
  };

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
    setAnchorEl(null);
  };

  var handleGroupByColumn = function handleGroupByColumn() {
    column.toggleGrouping();
    setColumnOrder(function (old) {
      return ['mrt-row-expand'].concat(old);
    });
    setAnchorEl(null);
  };

  var handleClearFilter = function handleClearFilter() {
    column.setFilterValue('');
    setAnchorEl(null);
  };

  var handleFilterByColumn = function handleFilterByColumn() {
    setShowFilters(true);
    setTimeout(function () {
      var _document$getElementB, _header$muiTableHeadC, _header$muiTableHeadC2;

      return (_document$getElementB = document.getElementById( // @ts-ignore
      (_header$muiTableHeadC = (_header$muiTableHeadC2 = header.muiTableHeadCellFilterTextFieldProps) == null ? void 0 : _header$muiTableHeadC2.id) != null ? _header$muiTableHeadC : "mrt-" + tableId + "-" + header.id + "-filter-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
    setAnchorEl(null);
  };

  var handleShowAllColumns = function handleShowAllColumns() {
    toggleAllColumnsVisible(true);
    setAnchorEl(null);
  };

  var handleOpenFilterModeMenu = function handleOpenFilterModeMenu(event) {
    event.stopPropagation();
    setFilterMenuAnchorEl(event.currentTarget);
  };

  var handleOpenShowHideColumnsMenu = function handleOpenShowHideColumnsMenu(event) {
    event.stopPropagation();
    setShowHideColumnsMenuAnchorEl(event.currentTarget);
  };

  var isSelectFilter = !!columnDef.filterSelectOptions;
  var allowedColumnFilterOptions = (_columnDef$columnFilt = columnDef == null ? void 0 : columnDef.columnFilterModeOptions) != null ? _columnDef$columnFilt : columnFilterModeOptions;
  var showFilterModeSubMenu = enableColumnFilterChangeMode && columnDef.enableColumnFilterChangeMode !== false && !isSelectFilter && (allowedColumnFilterOptions === undefined || !!(allowedColumnFilterOptions != null && allowedColumnFilterOptions.length));
  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: density === 'compact'
    }
  }, enableSorting && column.getCanSort() && [React__default.createElement(material.MenuItem, {
    disabled: !column.getIsSorted(),
    key: 0,
    onClick: handleClearSort,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(ClearAllIcon, null)), localization.clearSort)), React__default.createElement(material.MenuItem, {
    disabled: column.getIsSorted() === 'asc',
    key: 1,
    onClick: handleSortAsc,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(SortIcon, null)), (_localization$sortByC = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC.replace('{column}', String(columnDef.header)))), React__default.createElement(material.MenuItem, {
    divider: enableColumnFilters || enableGrouping || enableHiding,
    key: 2,
    disabled: column.getIsSorted() === 'desc',
    onClick: handleSortDesc,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(SortIcon, {
    style: {
      transform: 'rotate(180deg) scaleX(-1)'
    }
  })), (_localization$sortByC2 = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC2.replace('{column}', String(columnDef.header))))], enableColumnFilters && column.getCanFilter() && [React__default.createElement(material.MenuItem, {
    disabled: !column.getFilterValue(),
    key: 0,
    onClick: handleClearFilter,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(FilterListOffIcon, null)), localization.clearFilter)), React__default.createElement(material.MenuItem, {
    divider: enableGrouping || enableHiding,
    key: 1,
    onClick: handleFilterByColumn,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(FilterListIcon, null)), (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header))), showFilterModeSubMenu && React__default.createElement(material.IconButton, {
    onClick: handleOpenFilterModeMenu,
    onMouseEnter: handleOpenFilterModeMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React__default.createElement(ArrowRightIcon, null))), showFilterModeSubMenu && React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: filterMenuAnchorEl,
    header: header,
    key: 2,
    onSelect: handleFilterByColumn,
    setAnchorEl: setFilterMenuAnchorEl,
    table: table
  })].filter(Boolean), enableGrouping && column.getCanGroup() && [React__default.createElement(material.MenuItem, {
    divider: enablePinning,
    key: 0,
    onClick: handleGroupByColumn,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(DynamicFeedIcon, null)), (_localization = localization[column.getIsGrouped() ? 'ungroupByColumn' : 'groupByColumn']) == null ? void 0 : _localization.replace('{column}', String(columnDef.header))))], enablePinning && column.getCanPin() && [React__default.createElement(material.MenuItem, {
    disabled: column.getIsPinned() === 'left' || !column.getCanPin(),
    key: 0,
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  })), localization.pinToLeft)), React__default.createElement(material.MenuItem, {
    disabled: column.getIsPinned() === 'right' || !column.getCanPin(),
    key: 1,
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })), localization.pinToRight)), React__default.createElement(material.MenuItem, {
    disabled: !column.getIsPinned(),
    divider: enableHiding,
    key: 2,
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(PushPinIcon, null)), localization.unpin))], enableColumnResizing && column.getCanResize() && [React__default.createElement(material.MenuItem, {
    disabled: !columnSizing[column.id],
    key: 0,
    onClick: handleResetColumnSize,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(RestartAltIcon, null)), localization.resetColumnSize))], enableHiding && [React__default.createElement(material.MenuItem, {
    disabled: columnDef.enableHiding === false,
    key: 0,
    onClick: handleHideColumn,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(VisibilityOffIcon, null)), (_localization$hideCol = localization.hideColumn) == null ? void 0 : _localization$hideCol.replace('{column}', String(columnDef.header)))), React__default.createElement(material.MenuItem, {
    disabled: !Object.values(columnVisibility).filter(function (visible) {
      return !visible;
    }).length,
    key: 1,
    onClick: handleShowAllColumns,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(ViewColumnIcon, null)), (_localization$showAll = localization.showAllColumns) == null ? void 0 : _localization$showAll.replace('{column}', String(columnDef.header))), React__default.createElement(material.IconButton, {
    onClick: handleOpenShowHideColumnsMenu,
    onMouseEnter: handleOpenShowHideColumnsMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React__default.createElement(ArrowRightIcon, null))), React__default.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: showHideColumnsMenuAnchorEl,
    isSubMenu: true,
    key: 2,
    setAnchorEl: setShowHideColumnsMenuAnchorEl,
    table: table
  })]);
};

var MRT_RowActionMenu = function MRT_RowActionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      handleEdit = _ref.handleEdit,
      row = _ref.row,
      setAnchorEl = _ref.setAnchorEl,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      EditIcon = _table$options.icons.EditIcon,
      enableEditing = _table$options.enableEditing,
      localization = _table$options.localization,
      renderRowActionMenuItems = _table$options.renderRowActionMenuItems;

  var _getState = getState(),
      density = _getState.density;

  return React__default.createElement(material.Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: density === 'compact'
    }
  }, enableEditing && React__default.createElement(material.MenuItem, {
    onClick: handleEdit,
    sx: commonMenuItemStyles
  }, React__default.createElement(material.Box, {
    sx: commonListItemStyles
  }, React__default.createElement(material.ListItemIcon, null, React__default.createElement(EditIcon, null)), localization.edit)), renderRowActionMenuItems == null ? void 0 : renderRowActionMenuItems({
    row: row,
    table: table,
    closeMenu: function closeMenu() {
      return setAnchorEl(null);
    }
  }));
};

var MRT_EditActionButtons = function MRT_EditActionButtons(_ref) {
  var row = _ref.row,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      _table$options$icons = _table$options.icons,
      CancelIcon = _table$options$icons.CancelIcon,
      SaveIcon = _table$options$icons.SaveIcon,
      localization = _table$options.localization,
      onEditRowSubmit = _table$options.onEditRowSubmit,
      setCurrentEditingRow = table.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var handleCancel = function handleCancel() {
    var _row$original;

    row._valuesCache = (_row$original = row.original) != null ? _row$original : {};
    setCurrentEditingRow(null);
  };

  var handleSave = function handleSave() {
    onEditRowSubmit == null ? void 0 : onEditRowSubmit({
      row: currentEditingRow != null ? currentEditingRow : row,
      table: table
    });
    setCurrentEditingRow(null);
  };

  return React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      gap: '0.75rem'
    }
  }, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.cancel
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.cancel,
    onClick: handleCancel
  }, React__default.createElement(CancelIcon, null))), React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.save
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.save,
    color: "info",
    onClick: handleSave
  }, React__default.createElement(SaveIcon, null))));
};

var commonIconButtonStyles = {
  height: '2rem',
  ml: '10px',
  opacity: 0.5,
  transition: 'opacity 0.2s',
  width: '2rem',
  '&:hover': {
    opacity: 1
  }
};
var MRT_ToggleRowActionMenuButton = function MRT_ToggleRowActionMenuButton(_ref) {
  var row = _ref.row,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableEditing = _table$options.enableEditing,
      _table$options$icons = _table$options.icons,
      EditIcon = _table$options$icons.EditIcon,
      MoreHorizIcon = _table$options$icons.MoreHorizIcon,
      localization = _table$options.localization,
      renderRowActionMenuItems = _table$options.renderRowActionMenuItems,
      renderRowActions = _table$options.renderRowActions,
      setCurrentEditingRow = table.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleOpenRowActionMenu = function handleOpenRowActionMenu(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var handleStartEditMode = function handleStartEditMode() {
    setCurrentEditingRow(_extends({}, row));
    setAnchorEl(null);
  };

  return React__default.createElement(React__default.Fragment, null, renderRowActions ? React__default.createElement(React__default.Fragment, null, renderRowActions({
    row: row,
    table: table
  })) : row.id === (currentEditingRow == null ? void 0 : currentEditingRow.id) ? React__default.createElement(MRT_EditActionButtons, {
    row: row,
    table: table
  }) : !renderRowActionMenuItems && enableEditing ? React__default.createElement(material.Tooltip, {
    placement: "right",
    arrow: true,
    title: localization.edit
  }, React__default.createElement(material.IconButton, {
    sx: commonIconButtonStyles,
    onClick: handleStartEditMode
  }, React__default.createElement(EditIcon, null))) : renderRowActionMenuItems ? React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.rowActions
  }, React__default.createElement(material.IconButton, {
    "aria-label": localization.rowActions,
    onClick: handleOpenRowActionMenu,
    size: "small",
    sx: commonIconButtonStyles
  }, React__default.createElement(MoreHorizIcon, null))), React__default.createElement(MRT_RowActionMenu, {
    anchorEl: anchorEl,
    handleEdit: handleStartEditMode,
    row: row,
    setAnchorEl: setAnchorEl,
    table: table
  })) : null);
};

var MRT_SelectCheckbox = function MRT_SelectCheckbox(_ref) {
  var row = _ref.row,
      selectAll = _ref.selectAll,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      localization = _table$options.localization,
      muiSelectCheckboxProps = _table$options.muiSelectCheckboxProps,
      muiSelectAllCheckboxProps = _table$options.muiSelectAllCheckboxProps,
      selectAllMode = _table$options.selectAllMode;

  var _getState = getState(),
      density = _getState.density;

  var checkboxProps = !row ? muiSelectAllCheckboxProps instanceof Function ? muiSelectAllCheckboxProps({
    table: table
  }) : muiSelectAllCheckboxProps : muiSelectCheckboxProps instanceof Function ? muiSelectCheckboxProps({
    row: row,
    table: table
  }) : muiSelectCheckboxProps;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
  }, React__default.createElement(material.Checkbox, Object.assign({
    checked: selectAll ? table.getIsAllRowsSelected() : row == null ? void 0 : row.getIsSelected(),
    indeterminate: selectAll ? table.getIsSomeRowsSelected() : row == null ? void 0 : row.getIsSomeSelected(),
    inputProps: {
      'aria-label': selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
    },
    onChange: !row ? selectAllMode === 'all' ? table.getToggleAllRowsSelectedHandler() : table.getToggleAllPageRowsSelectedHandler() : row.getToggleSelectedHandler(),
    size: density === 'compact' ? 'small' : 'medium'
  }, checkboxProps, {
    sx: function sx(theme) {
      return _extends({
        height: density === 'compact' ? '1.75rem' : '2.5rem',
        width: density === 'compact' ? '1.75rem' : '2.5rem',
        m: density !== 'compact' ? '-0.4rem' : undefined
      }, (checkboxProps == null ? void 0 : checkboxProps.sx) instanceof Function ? checkboxProps.sx(theme) : checkboxProps == null ? void 0 : checkboxProps.sx);
    }
  })));
};

var MRT_GlobalFilterTextField = function MRT_GlobalFilterTextField(_ref) {
  var _localization$clearSe;

  var table = _ref.table;
  var getState = table.getState,
      setGlobalFilter = table.setGlobalFilter,
      _table$options = table.options,
      enableGlobalFilterChangeMode = _table$options.enableGlobalFilterChangeMode,
      _table$options$icons = _table$options.icons,
      SearchIcon = _table$options$icons.SearchIcon,
      CloseIcon = _table$options$icons.CloseIcon,
      localization = _table$options.localization,
      muiSearchTextFieldProps = _table$options.muiSearchTextFieldProps,
      tableId = _table$options.tableId;

  var _getState = getState(),
      globalFilter = _getState.globalFilter,
      showGlobalFilter = _getState.showGlobalFilter;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var _useState2 = React.useState(globalFilter != null ? globalFilter : ''),
      searchValue = _useState2[0],
      setSearchValue = _useState2[1];

  var handleChangeDebounced = React.useCallback(material.debounce(function (event) {
    var _event$target$value;

    setGlobalFilter((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
  }, 250), []);

  var handleChange = function handleChange(event) {
    setSearchValue(event.target.value);
    handleChangeDebounced(event);
  };

  var handleGlobalFilterMenuOpen = function handleGlobalFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setSearchValue('');
    setGlobalFilter(undefined);
  };

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    table: table
  }) : muiSearchTextFieldProps;
  return React__default.createElement(material.Collapse, {
    "in": showGlobalFilter,
    orientation: "horizontal"
  }, React__default.createElement(material.TextField, Object.assign({
    id: "mrt-" + tableId + "-search-text-field",
    placeholder: localization.search,
    onChange: handleChange,
    value: searchValue != null ? searchValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: enableGlobalFilterChangeMode ? React__default.createElement(material.InputAdornment, {
        position: "start"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        title: localization.changeSearchMode
      }, React__default.createElement(material.IconButton, {
        "aria-label": localization.changeSearchMode,
        onClick: handleGlobalFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(SearchIcon, null)))) : React__default.createElement(SearchIcon, null),
      endAdornment: React__default.createElement(material.InputAdornment, {
        position: "end"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        title: (_localization$clearSe = localization.clearSearch) != null ? _localization$clearSe : ''
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.clearSearch,
        disabled: !(searchValue != null && searchValue.length),
        onClick: handleClear,
        size: "small"
      }, React__default.createElement(CloseIcon, null)))))
    }
  }, textFieldProps)), React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    table: table
  }));
};

var MRT_LinearProgressBar = function MRT_LinearProgressBar(_ref) {
  var isTopToolbar = _ref.isTopToolbar,
      table = _ref.table;
  var muiLinearProgressProps = table.options.muiLinearProgressProps,
      getState = table.getState;

  var _getState = getState(),
      isLoading = _getState.isLoading,
      showProgressBars = _getState.showProgressBars;

  var linearProgressProps = muiLinearProgressProps instanceof Function ? muiLinearProgressProps({
    isTopToolbar: isTopToolbar,
    table: table
  }) : muiLinearProgressProps;
  return React__default.createElement(material.Collapse, {
    "in": isLoading || showProgressBars,
    mountOnEnter: true,
    unmountOnExit: true,
    sx: {
      bottom: isTopToolbar ? 0 : undefined,
      position: 'absolute',
      top: !isTopToolbar ? 0 : undefined,
      width: '100%'
    }
  }, React__default.createElement(material.LinearProgress, Object.assign({
    "aria-label": "Loading",
    "aria-busy": "true",
    sx: {
      position: 'relative'
    }
  }, linearProgressProps)));
};

var MRT_TablePagination = function MRT_TablePagination(_ref) {
  var table = _ref.table,
      position = _ref.position;
  var getPrePaginationRowModel = table.getPrePaginationRowModel,
      getState = table.getState,
      setPageIndex = table.setPageIndex,
      setPageSize = table.setPageSize,
      _table$options = table.options,
      muiTablePaginationProps = _table$options.muiTablePaginationProps,
      enableToolbarInternalActions = _table$options.enableToolbarInternalActions,
      rowCount = _table$options.rowCount;

  var _getState = getState(),
      _getState$pagination = _getState.pagination,
      _getState$pagination$ = _getState$pagination.pageSize,
      pageSize = _getState$pagination$ === void 0 ? 10 : _getState$pagination$,
      _getState$pagination$2 = _getState$pagination.pageIndex,
      pageIndex = _getState$pagination$2 === void 0 ? 0 : _getState$pagination$2,
      showGlobalFilter = _getState.showGlobalFilter;

  var totalRowCount = rowCount != null ? rowCount : getPrePaginationRowModel().rows.length;
  var showFirstLastPageButtons = totalRowCount / pageSize > 2;
  var tablePaginationProps = muiTablePaginationProps instanceof Function ? muiTablePaginationProps({
    table: table
  }) : muiTablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    setPageSize(+event.target.value);
  };

  return React__default.createElement(material.TablePagination, Object.assign({
    SelectProps: {
      sx: {
        m: '0 1rem 0 1ch'
      },
      MenuProps: {
        MenuListProps: {
          disablePadding: true
        }
      }
    },
    component: "div",
    count: totalRowCount,
    onPageChange: function onPageChange(_, newPage) {
      return setPageIndex(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: pageIndex,
    rowsPerPage: pageSize,
    rowsPerPageOptions: [5, 10, 15, 20, 25, 30, 50, 100],
    showFirstButton: showFirstLastPageButtons,
    showLastButton: showFirstLastPageButtons
  }, tablePaginationProps, {
    sx: function sx(theme) {
      return _extends({
        m: '0 0.5rem',
        mt: position === 'top' && enableToolbarInternalActions && !showGlobalFilter ? '3.5rem' : undefined,
        position: 'relative',
        zIndex: 2
      }, (tablePaginationProps == null ? void 0 : tablePaginationProps.sx) instanceof Function ? tablePaginationProps.sx(theme) : tablePaginationProps == null ? void 0 : tablePaginationProps.sx);
    }
  }));
};

var MRT_ToolbarAlertBanner = function MRT_ToolbarAlertBanner(_ref) {
  var _localization$selecte, _localization$selecte2;

  var stackAlertBanner = _ref.stackAlertBanner,
      table = _ref.table;
  var getPrePaginationRowModel = table.getPrePaginationRowModel,
      getSelectedRowModel = table.getSelectedRowModel,
      getState = table.getState,
      _table$options = table.options,
      localization = _table$options.localization,
      muiTableToolbarAlertBannerProps = _table$options.muiTableToolbarAlertBannerProps;

  var _getState = getState(),
      grouping = _getState.grouping,
      showAlertBanner = _getState.showAlertBanner;

  var alertProps = muiTableToolbarAlertBannerProps instanceof Function ? muiTableToolbarAlertBannerProps({
    table: table
  }) : muiTableToolbarAlertBannerProps;
  var selectMessage = getSelectedRowModel().rows.length > 0 ? (_localization$selecte = localization.selectedCountOfRowCountRowsSelected) == null ? void 0 : (_localization$selecte2 = _localization$selecte.replace('{selectedCount}', getSelectedRowModel().rows.length.toString())) == null ? void 0 : _localization$selecte2.replace('{rowCount}', getPrePaginationRowModel().rows.length.toString()) : null;
  var groupedByMessage = grouping.length > 0 ? React__default.createElement("span", null, localization.groupedBy, ' ', grouping.map(function (columnId, index) {
    return React__default.createElement(React.Fragment, {
      key: index + "-" + columnId
    }, index > 0 ? localization.thenBy : '', React__default.createElement(material.Chip, {
      color: "secondary",
      label: table.getColumn(columnId).columnDef.header,
      onDelete: function onDelete() {
        return table.getColumn(columnId).toggleGrouping();
      }
    }));
  })) : null;
  return React__default.createElement(material.Collapse, {
    "in": showAlertBanner || !!selectMessage || !!groupedByMessage,
    timeout: stackAlertBanner ? 200 : 0
  }, React__default.createElement(material.Alert, Object.assign({
    color: "info",
    icon: false
  }, alertProps, {
    sx: function sx(theme) {
      return _extends({
        borderRadius: 0,
        fontSize: '1rem',
        left: 0,
        p: 0,
        position: 'relative',
        right: 0,
        top: 0,
        width: '100%',
        zIndex: 2
      }, (alertProps == null ? void 0 : alertProps.sx) instanceof Function ? alertProps.sx(theme) : alertProps == null ? void 0 : alertProps.sx);
    }
  }), (alertProps == null ? void 0 : alertProps.title) && React__default.createElement(material.AlertTitle, null, alertProps.title), React__default.createElement(material.Box, {
    sx: {
      p: '0.5rem 1rem'
    }
  }, alertProps == null ? void 0 : alertProps.children, (alertProps == null ? void 0 : alertProps.children) && (selectMessage || groupedByMessage) && React__default.createElement("br", null), selectMessage, selectMessage && groupedByMessage && React__default.createElement("br", null), groupedByMessage)));
};

var _excluded = ["table"];
var MRT_FullScreenToggleButton = function MRT_FullScreenToggleButton(_ref) {
  var table = _ref.table,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var getState = table.getState,
      _table$options = table.options,
      _table$options$icons = _table$options.icons,
      FullscreenExitIcon = _table$options$icons.FullscreenExitIcon,
      FullscreenIcon = _table$options$icons.FullscreenIcon,
      localization = _table$options.localization,
      setIsFullScreen = table.setIsFullScreen;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var handleToggleFullScreen = function handleToggleFullScreen() {
    setIsFullScreen(!isFullScreen);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.toggleFullScreen
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleFullScreen
  }, rest), isFullScreen ? React__default.createElement(FullscreenExitIcon, null) : React__default.createElement(FullscreenIcon, null)));
};

var _excluded$1 = ["table"];
var MRT_ShowHideColumnsButton = function MRT_ShowHideColumnsButton(_ref) {
  var table = _ref.table,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _table$options = table.options,
      ViewColumnIcon = _table$options.icons.ViewColumnIcon,
      localization = _table$options.localization;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideColumns
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideColumns,
    onClick: handleClick
  }, rest), React__default.createElement(ViewColumnIcon, null))), React__default.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    table: table
  }));
};

var _excluded$2 = ["table"];
var MRT_ToggleDensePaddingButton = function MRT_ToggleDensePaddingButton(_ref) {
  var table = _ref.table,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  var getState = table.getState,
      _table$options = table.options,
      _table$options$icons = _table$options.icons,
      DensityLargeIcon = _table$options$icons.DensityLargeIcon,
      DensityMediumIcon = _table$options$icons.DensityMediumIcon,
      DensitySmallIcon = _table$options$icons.DensitySmallIcon,
      localization = _table$options.localization,
      setDensity = table.setDensity;

  var _getState = getState(),
      density = _getState.density;

  var handleToggleDensePadding = function handleToggleDensePadding() {
    var nextDensity = density === 'comfortable' ? 'compact' : density === 'compact' ? 'spacious' : 'comfortable';
    setDensity(nextDensity);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.toggleDensity
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.toggleDensity,
    onClick: handleToggleDensePadding
  }, rest), density === 'compact' ? React__default.createElement(DensitySmallIcon, null) : density === 'comfortable' ? React__default.createElement(DensityMediumIcon, null) : React__default.createElement(DensityLargeIcon, null)));
};

var _excluded$3 = ["table"];
var MRT_ToggleFiltersButton = function MRT_ToggleFiltersButton(_ref) {
  var table = _ref.table,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$3);

  var getState = table.getState,
      _table$options = table.options,
      _table$options$icons = _table$options.icons,
      FilterListIcon = _table$options$icons.FilterListIcon,
      FilterListOffIcon = _table$options$icons.FilterListOffIcon,
      localization = _table$options.localization,
      setShowFilters = table.setShowFilters;

  var _getState = getState(),
      showColumnFilters = _getState.showColumnFilters;

  var handleToggleShowFilters = function handleToggleShowFilters() {
    setShowFilters(!showColumnFilters);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideFilters
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: handleToggleShowFilters
  }, rest), showColumnFilters ? React__default.createElement(FilterListOffIcon, null) : React__default.createElement(FilterListIcon, null)));
};

var _excluded$4 = ["table"];
var MRT_ToggleGlobalFilterButton = function MRT_ToggleGlobalFilterButton(_ref) {
  var table = _ref.table,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$4);

  var getState = table.getState,
      _table$options = table.options,
      _table$options$icons = _table$options.icons,
      SearchIcon = _table$options$icons.SearchIcon,
      SearchOffIcon = _table$options$icons.SearchOffIcon,
      tableId = _table$options.tableId,
      localization = _table$options.localization,
      muiSearchTextFieldProps = _table$options.muiSearchTextFieldProps,
      setShowGlobalFilter = table.setShowGlobalFilter;

  var _getState = getState(),
      showGlobalFilter = _getState.showGlobalFilter;

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    table: table
  }) : muiSearchTextFieldProps;

  var handleToggleSearch = function handleToggleSearch() {
    setShowGlobalFilter(!showGlobalFilter);
    setTimeout(function () {
      var _document$getElementB, _textFieldProps$id;

      return (_document$getElementB = document.getElementById((_textFieldProps$id = textFieldProps == null ? void 0 : textFieldProps.id) != null ? _textFieldProps$id : "mrt-" + tableId + "-search-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
  };

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    title: localization.showHideSearch
  }, React__default.createElement(material.IconButton, Object.assign({
    onClick: handleToggleSearch
  }, rest), showGlobalFilter ? React__default.createElement(SearchOffIcon, null) : React__default.createElement(SearchIcon, null)));
};

var MRT_ToolbarInternalButtons = function MRT_ToolbarInternalButtons(_ref) {
  var _renderToolbarInterna;

  var table = _ref.table;
  var _table$options = table.options,
      enableColumnFilters = _table$options.enableColumnFilters,
      enableColumnOrdering = _table$options.enableColumnOrdering,
      enableDensityToggle = _table$options.enableDensityToggle,
      enableFilters = _table$options.enableFilters,
      enableFullScreenToggle = _table$options.enableFullScreenToggle,
      enableGlobalFilter = _table$options.enableGlobalFilter,
      enableHiding = _table$options.enableHiding,
      enablePinning = _table$options.enablePinning,
      positionGlobalFilter = _table$options.positionGlobalFilter,
      renderToolbarInternalActions = _table$options.renderToolbarInternalActions;
  return React__default.createElement(material.Box, {
    sx: {
      alignItems: 'center',
      display: 'flex',
      zIndex: 3
    }
  }, (_renderToolbarInterna = renderToolbarInternalActions == null ? void 0 : renderToolbarInternalActions({
    MRT_FullScreenToggleButton: MRT_FullScreenToggleButton,
    MRT_ShowHideColumnsButton: MRT_ShowHideColumnsButton,
    MRT_ToggleDensePaddingButton: MRT_ToggleDensePaddingButton,
    MRT_ToggleFiltersButton: MRT_ToggleFiltersButton,
    MRT_ToggleGlobalFilterButton: MRT_ToggleGlobalFilterButton,
    table: table
  })) != null ? _renderToolbarInterna : React__default.createElement(React__default.Fragment, null, enableGlobalFilter && positionGlobalFilter === 'right' && React__default.createElement(MRT_GlobalFilterTextField, {
    table: table
  }), enableFilters && enableGlobalFilter && React__default.createElement(MRT_ToggleGlobalFilterButton, {
    table: table
  }), enableFilters && enableColumnFilters && React__default.createElement(MRT_ToggleFiltersButton, {
    table: table
  }), (enableHiding || enableColumnOrdering || enablePinning) && React__default.createElement(MRT_ShowHideColumnsButton, {
    table: table
  }), enableDensityToggle && React__default.createElement(MRT_ToggleDensePaddingButton, {
    table: table
  }), enableFullScreenToggle && React__default.createElement(MRT_FullScreenToggleButton, {
    table: table
  })));
};

var commonToolbarStyles = function commonToolbarStyles(_ref) {
  var theme = _ref.theme;
  return {
    alignItems: 'flex-start',
    backgroundColor: material.lighten(theme.palette.background["default"], 0.04),
    backgroundImage: 'none',
    display: 'grid',
    minHeight: '3.5rem',
    overflow: 'hidden',
    p: '0 !important',
    transition: 'all 0.2s ease-in-out',
    zIndex: 1
  };
};
var MRT_ToolbarTop = function MRT_ToolbarTop(_ref2) {
  var _renderToolbarTopCust;

  var table = _ref2.table;
  var getState = table.getState,
      _table$options = table.options,
      enableGlobalFilter = _table$options.enableGlobalFilter,
      enablePagination = _table$options.enablePagination,
      enableToolbarInternalActions = _table$options.enableToolbarInternalActions,
      muiTableToolbarTopProps = _table$options.muiTableToolbarTopProps,
      positionGlobalFilter = _table$options.positionGlobalFilter,
      positionPagination = _table$options.positionPagination,
      positionToolbarAlertBanner = _table$options.positionToolbarAlertBanner,
      renderToolbarTopCustomActions = _table$options.renderToolbarTopCustomActions,
      tableId = _table$options.tableId;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen,
      showGlobalFilter = _getState.showGlobalFilter;

  var isMobile = material.useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarTopProps instanceof Function ? muiTableToolbarTopProps({
    table: table
  }) : muiTableToolbarTopProps;
  var stackAlertBanner = isMobile || !!renderToolbarTopCustomActions || showGlobalFilter;
  return React__default.createElement(material.Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-top",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        position: isFullScreen ? 'sticky' : undefined,
        top: isFullScreen ? '0' : undefined
      }, commonToolbarStyles({
        theme: theme
      }), (toolbarProps == null ? void 0 : toolbarProps.sx) instanceof Function ? toolbarProps.sx(theme) : toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), positionToolbarAlertBanner === 'top' && React__default.createElement(MRT_ToolbarAlertBanner, {
    stackAlertBanner: stackAlertBanner,
    table: table
  }), React__default.createElement(material.Box, {
    sx: {
      alignItems: 'flex-start',
      boxSizing: 'border-box',
      display: 'flex',
      justifyContent: 'space-between',
      p: '0.5rem',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0,
      width: '100%'
    }
  }, enableGlobalFilter && positionGlobalFilter === 'left' && React__default.createElement(MRT_GlobalFilterTextField, {
    table: table
  }), (_renderToolbarTopCust = renderToolbarTopCustomActions == null ? void 0 : renderToolbarTopCustomActions({
    table: table
  })) != null ? _renderToolbarTopCust : React__default.createElement("span", null), enableToolbarInternalActions ? React__default.createElement(MRT_ToolbarInternalButtons, {
    table: table
  }) : enableGlobalFilter && positionGlobalFilter === 'right' && React__default.createElement(MRT_GlobalFilterTextField, {
    table: table
  })), enablePagination && ['top', 'both'].includes(positionPagination != null ? positionPagination : '') && React__default.createElement(MRT_TablePagination, {
    table: table,
    position: "top"
  }), React__default.createElement(MRT_LinearProgressBar, {
    isTopToolbar: true,
    table: table
  }));
};

var MRT_ToolbarBottom = function MRT_ToolbarBottom(_ref) {
  var table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enablePagination = _table$options.enablePagination,
      muiTableToolbarBottomProps = _table$options.muiTableToolbarBottomProps,
      positionPagination = _table$options.positionPagination,
      positionToolbarAlertBanner = _table$options.positionToolbarAlertBanner,
      renderToolbarBottomCustomActions = _table$options.renderToolbarBottomCustomActions,
      tableId = _table$options.tableId;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var isMobile = material.useMediaQuery('(max-width:720px)');
  var toolbarProps = muiTableToolbarBottomProps instanceof Function ? muiTableToolbarBottomProps({
    table: table
  }) : muiTableToolbarBottomProps;
  var stackAlertBanner = isMobile || !!renderToolbarBottomCustomActions;
  return React__default.createElement(material.Toolbar, Object.assign({
    id: "mrt-" + tableId + "-toolbar-bottom",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({}, commonToolbarStyles({
        theme: theme
      }), {
        bottom: isFullScreen ? '0' : undefined,
        boxShadow: "-3px 0 6px " + material.alpha(theme.palette.common.black, 0.1),
        left: 0,
        position: isFullScreen ? 'fixed' : 'relative',
        right: 0
      }, (toolbarProps == null ? void 0 : toolbarProps.sx) instanceof Function ? toolbarProps.sx(theme) : toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), React__default.createElement(MRT_LinearProgressBar, {
    isTopToolbar: false,
    table: table
  }), positionToolbarAlertBanner === 'bottom' && React__default.createElement(MRT_ToolbarAlertBanner, {
    table: table
  }), React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      width: '100%'
    }
  }, renderToolbarBottomCustomActions ? React__default.createElement(material.Box, {
    sx: {
      p: '0.5rem'
    }
  }, renderToolbarBottomCustomActions({
    table: table
  })) : React__default.createElement("span", null), React__default.createElement(material.Box, {
    sx: {
      display: 'flex',
      justifyContent: 'flex-end',
      position: stackAlertBanner ? 'relative' : 'absolute',
      right: 0,
      top: 0
    }
  }, enablePagination && ['bottom', 'both'].includes(positionPagination != null ? positionPagination : '') && React__default.createElement(MRT_TablePagination, {
    table: table,
    position: "bottom"
  }))));
};

var MRT_TableHeadCellColumnActionsButton = function MRT_TableHeadCellColumnActionsButton(_ref) {
  var header = _ref.header,
      table = _ref.table;
  var _table$options = table.options,
      MoreVertIcon = _table$options.icons.MoreVertIcon,
      localization = _table$options.localization,
      muiTableHeadCellColumnActionsButtonProps = _table$options.muiTableHeadCellColumnActionsButtonProps;
  var column = header.column;
  var columnDef = column.columnDef;

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var mTableHeadCellColumnActionsButtonProps = muiTableHeadCellColumnActionsButtonProps instanceof Function ? muiTableHeadCellColumnActionsButtonProps({
    column: column,
    table: table
  }) : muiTableHeadCellColumnActionsButtonProps;
  var mcTableHeadCellColumnActionsButtonProps = columnDef.muiTableHeadCellColumnActionsButtonProps instanceof Function ? columnDef.muiTableHeadCellColumnActionsButtonProps({
    column: column,
    table: table
  }) : columnDef.muiTableHeadCellColumnActionsButtonProps;

  var iconButtonProps = _extends({}, mTableHeadCellColumnActionsButtonProps, mcTableHeadCellColumnActionsButtonProps);

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.columnActions
  }, React__default.createElement(material.IconButton, Object.assign({
    "aria-label": localization.columnActions,
    onClick: handleClick,
    size: "small"
  }, iconButtonProps, {
    sx: function sx(theme) {
      return _extends({
        height: '2rem',
        mt: '-0.2rem',
        opacity: 0.5,
        transition: 'opacity 0.2s',
        width: '2rem',
        '&:hover': {
          opacity: 1
        }
      }, (iconButtonProps == null ? void 0 : iconButtonProps.sx) instanceof Function ? iconButtonProps.sx(theme) : iconButtonProps == null ? void 0 : iconButtonProps.sx);
    }
  }), React__default.createElement(MoreVertIcon, null))), React__default.createElement(MRT_ColumnActionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    table: table
  }));
};

var MRT_FilterTextField = function MRT_FilterTextField(_ref) {
  var _currentFilterOption$, _localization$filterB, _columnDef$columnFilt, _currentFilterOption$2, _localization$clearFi, _columnDef$filterSele;

  var header = _ref.header,
      rangeFilterIndex = _ref.rangeFilterIndex,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableColumnFilterChangeMode = _table$options.enableColumnFilterChangeMode,
      columnFilterModeOptions = _table$options.columnFilterModeOptions,
      _table$options$icons = _table$options.icons,
      FilterListIcon = _table$options$icons.FilterListIcon,
      CloseIcon = _table$options$icons.CloseIcon,
      localization = _table$options.localization,
      muiTableHeadCellFilterTextFieldProps = _table$options.muiTableHeadCellFilterTextFieldProps,
      tableId = _table$options.tableId,
      setCurrentFilterFns = table.setCurrentFilterFns;
  var column = header.column;
  var columnDef = column.columnDef;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns;

  var mTableHeadCellFilterTextFieldProps = muiTableHeadCellFilterTextFieldProps instanceof Function ? muiTableHeadCellFilterTextFieldProps({
    column: column,
    table: table,
    rangeFilterIndex: rangeFilterIndex
  }) : muiTableHeadCellFilterTextFieldProps;
  var mcTableHeadCellFilterTextFieldProps = columnDef.muiTableHeadCellFilterTextFieldProps instanceof Function ? columnDef.muiTableHeadCellFilterTextFieldProps({
    column: column,
    table: table,
    rangeFilterIndex: rangeFilterIndex
  }) : columnDef.muiTableHeadCellFilterTextFieldProps;

  var textFieldProps = _extends({}, mTableHeadCellFilterTextFieldProps, mcTableHeadCellFilterTextFieldProps);

  var isRangeFilter = columnDef.filterVariant === 'range' || rangeFilterIndex !== undefined;
  var isSelectFilter = columnDef.filterVariant === 'select';
  var isMultiSelectFilter = columnDef.filterVariant === 'multi-select';
  var isTextboxFilter = columnDef.filterVariant === 'text' || !isSelectFilter && !isMultiSelectFilter;
  var currentFilterOption = currentFilterFns == null ? void 0 : currentFilterFns[header.id];
  var filterId = "mrt-" + tableId + "-" + header.id + "-filter-text-field" + (rangeFilterIndex != null ? rangeFilterIndex : '');
  var filterChipLabel = ['empty', 'notEmpty'].includes(currentFilterOption) ? //@ts-ignore
  localization["filter" + ((currentFilterOption == null ? void 0 : currentFilterOption.charAt == null ? void 0 : (_currentFilterOption$ = currentFilterOption.charAt(0)) == null ? void 0 : _currentFilterOption$.toUpperCase()) + (currentFilterOption == null ? void 0 : currentFilterOption.slice(1)))] : '';
  var filterPlaceholder = !isRangeFilter ? (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(columnDef.header)) : rangeFilterIndex === 0 ? localization.min : rangeFilterIndex === 1 ? localization.max : '';
  var allowedColumnFilterOptions = (_columnDef$columnFilt = columnDef == null ? void 0 : columnDef.columnFilterModeOptions) != null ? _columnDef$columnFilt : columnFilterModeOptions;
  var showChangeModeButton = enableColumnFilterChangeMode && columnDef.enableColumnFilterChangeMode !== false && !rangeFilterIndex && (allowedColumnFilterOptions === undefined || !!(allowedColumnFilterOptions != null && allowedColumnFilterOptions.length));

  var _useState = React.useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var _useState2 = React.useState(function () {
    var _column$getFilterValu, _column$getFilterValu2;

    return isMultiSelectFilter ? column.getFilterValue() || [] : isRangeFilter ? ((_column$getFilterValu = column.getFilterValue()) == null ? void 0 : _column$getFilterValu[rangeFilterIndex]) || [] : (_column$getFilterValu2 = column.getFilterValue()) != null ? _column$getFilterValu2 : '';
  }),
      filterValue = _useState2[0],
      setFilterValue = _useState2[1];

  var handleChangeDebounced = React.useCallback(material.debounce(function (event) {
    var value = textFieldProps.type === 'date' ? new Date(event.target.value) : event.target.value;

    if (isRangeFilter) {
      column.setFilterValue(function (old) {
        var newFilterValues = old != null ? old : ['', ''];
        newFilterValues[rangeFilterIndex] = value;
        return newFilterValues;
      });
    } else {
      column.setFilterValue(value != null ? value : undefined);
    }
  }, isTextboxFilter ? 200 : 1), []);

  var handleChange = function handleChange(event) {
    setFilterValue(event.target.value);
    handleChangeDebounced(event);
  };

  var handleClear = function handleClear() {
    if (isMultiSelectFilter) {
      setFilterValue([]);
      column.setFilterValue([]);
    } else if (isRangeFilter) {
      setFilterValue('');
      column.setFilterValue(function (old) {
        var newFilterValues = old != null ? old : ['', ''];
        newFilterValues[rangeFilterIndex] = undefined;
        return newFilterValues;
      });
    } else {
      setFilterValue('');
      column.setFilterValue(undefined);
    }
  };

  var handleClearEmptyFilterChip = function handleClearEmptyFilterChip() {
    setFilterValue('');
    column.setFilterValue(undefined);
    setCurrentFilterFns(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = 'fuzzy', _extends2));
    });
  };

  var handleFilterMenuOpen = function handleFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  if (columnDef.Filter) {
    return React__default.createElement(React__default.Fragment, null, columnDef.Filter == null ? void 0 : columnDef.Filter({
      header: header,
      table: table
    }));
  }

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.TextField, Object.assign({
    fullWidth: true,
    id: filterId,
    inputProps: {
      disabled: !!filterChipLabel,
      sx: {
        textOverflow: 'ellipsis',
        width: filterChipLabel ? 0 : undefined
      },
      title: filterPlaceholder
    },
    helperText: showChangeModeButton ? React__default.createElement("label", {
      htmlFor: filterId
    }, localization.filterMode.replace('{filterType}', // @ts-ignore
    localization["filter" + ((currentFilterOption == null ? void 0 : (_currentFilterOption$2 = currentFilterOption.charAt(0)) == null ? void 0 : _currentFilterOption$2.toUpperCase()) + (currentFilterOption == null ? void 0 : currentFilterOption.slice(1)))])) : null,
    FormHelperTextProps: {
      sx: {
        fontSize: '0.6rem',
        lineHeight: '0.8rem',
        whiteSpace: 'nowrap'
      }
    },
    margin: "none",
    placeholder: filterChipLabel || isSelectFilter || isMultiSelectFilter ? undefined : filterPlaceholder,
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    select: isSelectFilter || isMultiSelectFilter,
    value: filterValue,
    variant: "standard",
    InputProps: {
      startAdornment: showChangeModeButton ? React__default.createElement(material.InputAdornment, {
        position: "start"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        title: localization.changeFilterMode
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.changeFilterMode,
        onClick: handleFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(FilterListIcon, null)))), filterChipLabel && React__default.createElement(material.Chip, {
        onDelete: handleClearEmptyFilterChip,
        label: filterChipLabel
      })) : React__default.createElement(FilterListIcon, null),
      endAdornment: !filterChipLabel && React__default.createElement(material.InputAdornment, {
        position: "end"
      }, React__default.createElement(material.Tooltip, {
        arrow: true,
        placement: "right",
        title: (_localization$clearFi = localization.clearFilter) != null ? _localization$clearFi : ''
      }, React__default.createElement("span", null, React__default.createElement(material.IconButton, {
        "aria-label": localization.clearFilter,
        disabled: !(filterValue != null && filterValue.length),
        onClick: handleClear,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React__default.createElement(CloseIcon, null)))))
    },
    SelectProps: {
      displayEmpty: true,
      multiple: isMultiSelectFilter,
      renderValue: isMultiSelectFilter ? function (selected) {
        return !(selected != null && selected.length) ? React__default.createElement(material.Box, {
          sx: {
            opacity: 0.5
          }
        }, filterPlaceholder) : React__default.createElement(material.Box, {
          sx: {
            display: 'flex',
            flexWrap: 'wrap',
            gap: '2px'
          }
        }, selected == null ? void 0 : selected.map(function (value) {
          return React__default.createElement(material.Chip, {
            key: value,
            label: value
          });
        }));
      } : undefined
    }
  }, textFieldProps, {
    sx: function sx(theme) {
      return _extends({
        p: 0,
        minWidth: !filterChipLabel ? '6rem' : 'auto',
        width: 'calc(100% + 0.5rem)',
        '&	.MuiSelect-icon': {
          mr: '1.5rem'
        }
      }, (textFieldProps == null ? void 0 : textFieldProps.sx) instanceof Function ? textFieldProps.sx(theme) : textFieldProps == null ? void 0 : textFieldProps.sx);
    }
  }), (isSelectFilter || isMultiSelectFilter) && React__default.createElement(material.MenuItem, {
    divider: true,
    disabled: true,
    hidden: true,
    value: ""
  }, React__default.createElement(material.Box, {
    sx: {
      opacity: 0.5
    }
  }, filterPlaceholder)), columnDef == null ? void 0 : (_columnDef$filterSele = columnDef.filterSelectOptions) == null ? void 0 : _columnDef$filterSele.map(function (option) {
    var _column$getFilterValu3;

    var value;
    var text;

    if (typeof option !== 'object') {
      value = option;
      text = option;
    } else {
      value = option.value;
      text = option.text;
    }

    return React__default.createElement(material.MenuItem, {
      key: value,
      value: value
    }, isMultiSelectFilter && React__default.createElement(material.Checkbox, {
      checked: ((_column$getFilterValu3 = column.getFilterValue()) != null ? _column$getFilterValu3 : []).includes(value),
      sx: {
        mr: '0.5rem'
      }
    }), React__default.createElement(material.ListItemText, null, text));
  })), React__default.createElement(MRT_FilterOptionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    table: table
  }));
};

var MRT_FilterRangeFields = function MRT_FilterRangeFields(_ref) {
  var header = _ref.header,
      table = _ref.table;
  return React__default.createElement(material.Box, {
    sx: {
      display: 'grid',
      gridTemplateColumns: '6fr 6fr',
      gap: '1rem'
    }
  }, React__default.createElement(MRT_FilterTextField, {
    header: header,
    rangeFilterIndex: 0,
    table: table
  }), React__default.createElement(MRT_FilterTextField, {
    header: header,
    rangeFilterIndex: 1,
    table: table
  }));
};

var MRT_TableHeadCellFilterContainer = function MRT_TableHeadCellFilterContainer(_ref) {
  var header = _ref.header,
      table = _ref.table;
  var getState = table.getState;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns,
      showColumnFilters = _getState.showColumnFilters;

  var column = header.column;
  return React__default.createElement(material.Collapse, {
    "in": showColumnFilters,
    mountOnEnter: true,
    unmountOnExit: true
  }, ['between', 'betweenInclusive', 'inNumberRange'].includes(currentFilterFns[column.id]) ? React__default.createElement(MRT_FilterRangeFields, {
    header: header,
    table: table
  }) : React__default.createElement(MRT_FilterTextField, {
    header: header,
    table: table
  }));
};

var MRT_TableHeadCellFilterLabel = function MRT_TableHeadCellFilterLabel(_ref) {
  var _currentFilterOption$, _column$getFilterValu, _column$getFilterValu2;

  var header = _ref.header,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      FilterAltIcon = _table$options.icons.FilterAltIcon,
      localization = _table$options.localization;

  var _getState = getState(),
      currentFilterFns = _getState.currentFilterFns;

  var column = header.column;
  var columnDef = column.columnDef;
  var isRangeFilter = ['between', 'betweenInclusive', 'inNumberRange'].includes(columnDef._filterFn);
  var currentFilterOption = currentFilterFns == null ? void 0 : currentFilterFns[header.id];
  var filterTooltip = localization.filteringByColumn.replace('{column}', String(columnDef.header)).replace('{filterType}', // @ts-ignore
  localization["filter" + ((currentFilterOption == null ? void 0 : (_currentFilterOption$ = currentFilterOption.charAt(0)) == null ? void 0 : _currentFilterOption$.toUpperCase()) + (currentFilterOption == null ? void 0 : currentFilterOption.slice(1)))]).replace('{filterValue}', "\"" + (Array.isArray(column.getFilterValue()) ? column.getFilterValue().join("\" " + (isRangeFilter ? localization.and : localization.or) + " \"") : column.getFilterValue()) + "\"").replace('" "', '');
  return React__default.createElement(material.Grow, {
    unmountOnExit: true,
    "in": !!column.getFilterValue() && isRangeFilter || !isRangeFilter && ( // @ts-ignore
    !!((_column$getFilterValu = column.getFilterValue()) != null && _column$getFilterValu[0]) || !!((_column$getFilterValu2 = column.getFilterValue()) != null && _column$getFilterValu2[1]))
  }, React__default.createElement("span", null, React__default.createElement(material.Tooltip, {
    arrow: true,
    placement: "top",
    title: filterTooltip
  }, React__default.createElement(material.IconButton, {
    disableRipple: true,
    onClick: function onClick(event) {
      event.stopPropagation();
    },
    size: "small",
    sx: {
      m: 0,
      opacity: 0.8,
      p: '2px',
      transform: 'scale(0.66)',
      width: '1.5ch'
    }
  }, React__default.createElement(FilterAltIcon, null)))));
};

var MRT_TableHeadCellGrabHandle = function MRT_TableHeadCellGrabHandle(_ref) {
  var column = _ref.column,
      table = _ref.table,
      tableHeadCellRef = _ref.tableHeadCellRef;
  var getState = table.getState,
      _table$options = table.options,
      enableColumnOrdering = _table$options.enableColumnOrdering,
      muiTableHeadCellDragHandleProps = _table$options.muiTableHeadCellDragHandleProps,
      onColumnDrop = _table$options.onColumnDrop,
      setColumnOrder = table.setColumnOrder,
      setCurrentDraggingColumn = table.setCurrentDraggingColumn,
      setCurrentHoveredColumn = table.setCurrentHoveredColumn;
  var columnDef = column.columnDef;

  var _getState = getState(),
      currentHoveredColumn = _getState.currentHoveredColumn,
      currentDraggingColumn = _getState.currentDraggingColumn,
      columnOrder = _getState.columnOrder;

  var mIconButtonProps = muiTableHeadCellDragHandleProps instanceof Function ? muiTableHeadCellDragHandleProps({
    column: column,
    table: table
  }) : muiTableHeadCellDragHandleProps;
  var mcIconButtonProps = columnDef.muiTableHeadCellDragHandleProps instanceof Function ? columnDef.muiTableHeadCellDragHandleProps({
    column: column,
    table: table
  }) : columnDef.muiTableHeadCellDragHandleProps;

  var iconButtonProps = _extends({}, mIconButtonProps, mcIconButtonProps);

  var handleDragStart = function handleDragStart(e) {
    setCurrentDraggingColumn(column);
    e.dataTransfer.setDragImage(tableHeadCellRef.current, 0, 0);
  };

  var handleDragEnd = function handleDragEnd(event) {
    onColumnDrop == null ? void 0 : onColumnDrop({
      event: event,
      draggedColumn: column,
      targetColumn: currentHoveredColumn
    });

    if (enableColumnOrdering && currentHoveredColumn && (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) !== (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id)) {
      setColumnOrder(reorderColumn(column, currentHoveredColumn, columnOrder));
    }

    setCurrentDraggingColumn(null);
    setCurrentHoveredColumn(null);
  };

  return React__default.createElement(MRT_GrabHandleButton, {
    iconButtonProps: iconButtonProps,
    onDragStart: handleDragStart,
    onDragEnd: handleDragEnd,
    table: table
  });
};

var MRT_TableHeadCellResizeHandle = function MRT_TableHeadCellResizeHandle(_ref) {
  var _getState$columnSizin;

  var header = _ref.header,
      table = _ref.table;
  var getState = table.getState,
      columnResizeMode = table.options.columnResizeMode;

  var _getState = getState(),
      density = _getState.density,
      showColumnFilters = _getState.showColumnFilters;

  var column = header.column;
  var columnDef = column.columnDef;
  var columnDefType = columnDef.columnDefType;
  return React__default.createElement(material.Divider, {
    flexItem: true,
    orientation: "vertical",
    onDoubleClick: function onDoubleClick() {
      return column.resetSize();
    },
    sx: function sx(theme) {
      return {
        borderRadius: '2px',
        borderRightWidth: '2px',
        cursor: 'col-resize',
        height: showColumnFilters && columnDefType === 'data' ? '4rem' : '2rem',
        mr: density === 'compact' ? '-0.5rem' : '-1rem',
        opacity: 0.8,
        position: 'absolute',
        right: '1px',
        touchAction: 'none',
        transition: column.getIsResizing() ? undefined : 'all 0.2s ease-in-out',
        userSelect: 'none',
        zIndex: 4,
        '&:active': {
          backgroundColor: theme.palette.info.main,
          opacity: 1
        }
      };
    },
    onMouseDown: header.getResizeHandler(),
    onTouchStart: header.getResizeHandler(),
    style: {
      transform: column.getIsResizing() ? "translateX(" + ((_getState$columnSizin = getState().columnSizingInfo.deltaOffset) != null ? _getState$columnSizin : 0) / (columnResizeMode === 'onChange' ? 16 : 1) + "px)" : 'none'
    }
  });
};

var MRT_TableHeadCellSortLabel = function MRT_TableHeadCellSortLabel(_ref) {
  var header = _ref.header,
      table = _ref.table;
  var localization = table.options.localization;
  var column = header.column;
  var columnDef = column.columnDef;
  var sortTooltip = !!column.getIsSorted() ? column.getIsSorted() === 'desc' ? localization.sortedByColumnDesc.replace('{column}', columnDef.header) : localization.sortedByColumnAsc.replace('{column}', columnDef.header) : localization.unsorted;
  return React__default.createElement(material.Tooltip, {
    arrow: true,
    placement: "top",
    title: sortTooltip
  }, React__default.createElement(material.TableSortLabel, {
    "aria-label": sortTooltip,
    active: !!column.getIsSorted(),
    direction: column.getIsSorted() ? column.getIsSorted() : undefined,
    sx: {
      width: '2ch',
      transform: 'translateX(-0.5ch)'
    }
  }));
};

var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _ref2, _columnDef$header$len, _columnDef$header;

  var header = _ref.header,
      table = _ref.table;
  var theme = material.useTheme();
  var getState = table.getState,
      _table$options = table.options,
      enableColumnActions = _table$options.enableColumnActions,
      enableColumnDragging = _table$options.enableColumnDragging,
      enableColumnOrdering = _table$options.enableColumnOrdering,
      enableColumnResizing = _table$options.enableColumnResizing,
      enableGrouping = _table$options.enableGrouping,
      enableMultiSort = _table$options.enableMultiSort,
      muiTableHeadCellProps = _table$options.muiTableHeadCellProps,
      setCurrentHoveredColumn = table.setCurrentHoveredColumn;

  var _getState = getState(),
      density = _getState.density,
      currentDraggingColumn = _getState.currentDraggingColumn,
      currentHoveredColumn = _getState.currentHoveredColumn;

  var column = header.column;
  var columnDef = column.columnDef;
  var columnDefType = columnDef.columnDefType;
  var mTableHeadCellProps = muiTableHeadCellProps instanceof Function ? muiTableHeadCellProps({
    column: column,
    table: table
  }) : muiTableHeadCellProps;
  var mcTableHeadCellProps = columnDef.muiTableHeadCellProps instanceof Function ? columnDef.muiTableHeadCellProps({
    column: column,
    table: table
  }) : columnDef.muiTableHeadCellProps;

  var tableCellProps = _extends({}, mTableHeadCellProps, mcTableHeadCellProps);

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && table.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (table.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  var handleDragEnter = function handleDragEnter(_e) {
    if (enableColumnOrdering && currentDraggingColumn) {
      setCurrentHoveredColumn(columnDef.enableColumnOrdering !== false ? column : null);
    }
  };

  var draggingBorder = (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id ? "1px dashed " + theme.palette.divider : (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) === column.id ? "2px dashed " + theme.palette.primary.main : undefined;
  var draggingBorders = draggingBorder ? {
    borderLeft: draggingBorder,
    borderRight: draggingBorder,
    borderTop: draggingBorder
  } : undefined;
  var headerElement = (_ref2 = (columnDef == null ? void 0 : columnDef.Header) instanceof Function ? columnDef == null ? void 0 : columnDef.Header == null ? void 0 : columnDef.Header({
    header: header,
    table: table
  }) : columnDef == null ? void 0 : columnDef.Header) != null ? _ref2 : columnDef.header;
  var tableHeadCellRef = React__default.useRef(null);
  return React__default.createElement(material.TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: header.colSpan,
    onDragEnter: handleDragEnter,
    ref: tableHeadCellRef
  }, tableCellProps, {
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() && columnDefType !== 'group' ? material.alpha(material.lighten(theme.palette.background["default"], 0.04), 0.95) : 'inherit',
        backgroundImage: 'inherit',
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : undefined,
        fontWeight: 'bold',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        overflow: 'visible',
        opacity: (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id || (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) === column.id ? 0.5 : 1,
        p: density === 'compact' ? '0.5rem' : density === 'comfortable' ? columnDefType === 'display' ? '0.75rem' : '1rem' : columnDefType === 'display' ? '1rem 1.25rem' : '1.5rem',
        pb: columnDefType === 'display' ? 0 : undefined,
        position: column.getIsPinned() && columnDefType !== 'group' ? 'sticky' : undefined,
        pt: columnDefType === 'group' ? 0 : density === 'compact' ? '0.25' : density === 'comfortable' ? '.75rem' : '1.25rem',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        transition: "all " + (enableColumnResizing ? 0 : '0.2s') + " ease-in-out",
        userSelect: enableMultiSort && column.getCanSort() ? 'none' : undefined,
        verticalAlign: 'top',
        zIndex: column.getIsResizing() || (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id ? 3 : column.getIsPinned() && columnDefType !== 'group' ? 2 : 1
      }, (tableCellProps == null ? void 0 : tableCellProps.sx) instanceof Function ? tableCellProps.sx(theme) : tableCellProps == null ? void 0 : tableCellProps.sx, draggingBorders, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: header.getSize()
      });
    }
  }), header.isPlaceholder ? null : React__default.createElement(material.Box, {
    sx: {
      alignItems: 'flex-start',
      display: 'flex',
      justifyContent: (tableCellProps == null ? void 0 : tableCellProps.align) === 'right' ? 'flex-end' : columnDefType === 'group' || (tableCellProps == null ? void 0 : tableCellProps.align) === 'center' ? 'center' : 'space-between',
      position: 'relative',
      width: '100%'
    }
  }, React__default.createElement(material.Box, {
    onClick: column.getToggleSortingHandler(),
    sx: {
      alignItems: 'center',
      cursor: column.getCanSort() && columnDefType !== 'group' ? 'pointer' : undefined,
      display: 'flex',
      flexWrap: 'nowrap',
      m: (tableCellProps == null ? void 0 : tableCellProps.align) === 'center' ? 'auto' : undefined,
      pl: (tableCellProps == null ? void 0 : tableCellProps.align) === 'center' && column.getCanSort() ? '1rem' : undefined,
      whiteSpace: ((_columnDef$header$len = (_columnDef$header = columnDef.header) == null ? void 0 : _columnDef$header.length) != null ? _columnDef$header$len : 0) < 24 ? 'nowrap' : 'normal'
    }
  }, headerElement, column.getCanSort() && React__default.createElement(MRT_TableHeadCellSortLabel, {
    header: header,
    table: table
  }), column.getCanFilter() && React__default.createElement(MRT_TableHeadCellFilterLabel, {
    header: header,
    table: table
  })), columnDefType !== 'group' && React__default.createElement(material.Box, {
    sx: {
      whiteSpace: 'nowrap'
    }
  }, (enableColumnDragging && columnDef.enableColumnDragging !== false || enableColumnOrdering && columnDef.enableColumnOrdering !== false || enableGrouping && columnDef.enableGrouping !== false) && React__default.createElement(MRT_TableHeadCellGrabHandle, {
    column: column,
    table: table,
    tableHeadCellRef: tableHeadCellRef
  }), (enableColumnActions || columnDef.enableColumnActions) && columnDef.enableColumnActions !== false && React__default.createElement(MRT_TableHeadCellColumnActionsButton, {
    header: header,
    table: table
  })), column.getCanResize() && React__default.createElement(MRT_TableHeadCellResizeHandle, {
    header: header,
    table: table
  })), column.getCanFilter() && React__default.createElement(MRT_TableHeadCellFilterContainer, {
    header: header,
    table: table
  }));
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup,
      table = _ref.table;
  var muiTableHeadRowProps = table.options.muiTableHeadRowProps;
  var tableRowProps = muiTableHeadRowProps instanceof Function ? muiTableHeadRowProps({
    headerGroup: headerGroup,
    table: table
  }) : muiTableHeadRowProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        boxShadow: "4px 0 8px " + material.alpha(theme.palette.common.black, 0.1),
        backgroundColor: material.lighten(theme.palette.background["default"], 0.04)
      }, tableRowProps == null ? void 0 : tableRowProps.sx);
    }
  }), headerGroup.headers.map(function (header, index) {
    return React__default.createElement(MRT_TableHeadCell, {
      header: header,
      key: header.id || index,
      table: table
    });
  }));
};

var MRT_TableHead = function MRT_TableHead(_ref) {
  var table = _ref.table;
  var getHeaderGroups = table.getHeaderGroups,
      muiTableHeadProps = table.options.muiTableHeadProps;
  var tableHeadProps = muiTableHeadProps instanceof Function ? muiTableHeadProps({
    table: table
  }) : muiTableHeadProps;
  return React__default.createElement(material.TableHead, Object.assign({}, tableHeadProps), getHeaderGroups().map(function (headerGroup) {
    return React__default.createElement(MRT_TableHeadRow, {
      headerGroup: headerGroup,
      key: headerGroup.id,
      table: table
    });
  }));
};

var MRT_EditCellTextField = function MRT_EditCellTextField(_ref) {
  var cell = _ref.cell,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      tableId = _table$options.tableId,
      enableEditing = _table$options.enableEditing,
      muiTableBodyCellEditTextFieldProps = _table$options.muiTableBodyCellEditTextFieldProps,
      onCellEditBlur = _table$options.onCellEditBlur,
      onCellEditChange = _table$options.onCellEditChange,
      setCurrentEditingCell = table.setCurrentEditingCell,
      setCurrentEditingRow = table.setCurrentEditingRow;
  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef;

  var _useState = React.useState(cell.getValue()),
      value = _useState[0],
      setValue = _useState[1];

  var handleChange = function handleChange(event) {
    setValue(event.target.value);
    columnDef.onCellEditChange == null ? void 0 : columnDef.onCellEditChange({
      event: event,
      cell: cell,
      table: table
    });
    onCellEditChange == null ? void 0 : onCellEditChange({
      event: event,
      cell: cell,
      table: table
    });
  };

  var handleBlur = function handleBlur(event) {
    if (getState().currentEditingRow) {
      if (!row._valuesCache) row._valuesCache = {};
      row._valuesCache[column.id] = value;
      setCurrentEditingRow(_extends({}, getState().currentEditingRow));
    }

    setCurrentEditingCell(null);
    columnDef.onCellEditBlur == null ? void 0 : columnDef.onCellEditBlur({
      event: event,
      cell: cell,
      table: table
    });
    onCellEditBlur == null ? void 0 : onCellEditBlur({
      event: event,
      cell: cell,
      table: table
    });
  };

  var mTableBodyCellEditTextFieldProps = muiTableBodyCellEditTextFieldProps instanceof Function ? muiTableBodyCellEditTextFieldProps({
    cell: cell,
    table: table
  }) : muiTableBodyCellEditTextFieldProps;
  var mcTableBodyCellEditTextFieldProps = columnDef.muiTableBodyCellEditTextFieldProps instanceof Function ? columnDef.muiTableBodyCellEditTextFieldProps({
    cell: cell,
    table: table
  }) : columnDef.muiTableBodyCellEditTextFieldProps;

  var textFieldProps = _extends({}, mTableBodyCellEditTextFieldProps, mcTableBodyCellEditTextFieldProps);

  if (enableEditing && columnDef.enableEditing !== false && columnDef.Edit) {
    return React__default.createElement(React__default.Fragment, null, columnDef.Edit == null ? void 0 : columnDef.Edit({
      cell: cell,
      table: table
    }));
  }

  return React__default.createElement(material.TextField, Object.assign({
    id: "mrt-" + tableId + "-edit-cell-text-field-" + cell.id,
    margin: "dense",
    onBlur: handleBlur,
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    placeholder: columnDef.header,
    value: value,
    variant: "standard"
  }, textFieldProps));
};

var MRT_CopyButton = function MRT_CopyButton(_ref) {
  var cell = _ref.cell,
      children = _ref.children,
      table = _ref.table;
  var _table$options = table.options,
      localization = _table$options.localization,
      muiTableBodyCellCopyButtonProps = _table$options.muiTableBodyCellCopyButtonProps;
  var column = cell.column;
  var columnDef = column.columnDef;

  var _useState = React.useState(false),
      copied = _useState[0],
      setCopied = _useState[1];

  var handleCopy = function handleCopy(text) {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(function () {
      return setCopied(false);
    }, 4000);
  };

  var mTableBodyCellCopyButtonProps = muiTableBodyCellCopyButtonProps instanceof Function ? muiTableBodyCellCopyButtonProps({
    cell: cell,
    table: table
  }) : muiTableBodyCellCopyButtonProps;
  var mcTableBodyCellCopyButtonProps = columnDef.muiTableBodyCellCopyButtonProps instanceof Function ? columnDef.muiTableBodyCellCopyButtonProps({
    cell: cell,
    table: table
  }) : columnDef.muiTableBodyCellCopyButtonProps;

  var buttonProps = _extends({}, mTableBodyCellCopyButtonProps, mcTableBodyCellCopyButtonProps);

  return React__default.createElement(material.Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: copied ? localization.copiedToClipboard : localization.clickToCopy
  }, React__default.createElement(material.Button, Object.assign({
    onClick: function onClick() {
      return handleCopy(cell.getValue());
    },
    size: "small",
    type: "button",
    variant: "text"
  }, buttonProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: 'transparent',
        border: 'none',
        color: 'inherit',
        cursor: 'copy',
        fontFamily: 'inherit',
        fontSize: 'inherit',
        letterSpacing: 'inherit',
        m: '-0.25rem',
        minWidth: 'unset',
        textAlign: 'inherit',
        textTransform: 'inherit'
      }, (buttonProps == null ? void 0 : buttonProps.sx) instanceof Function ? buttonProps.sx(theme) : buttonProps == null ? void 0 : buttonProps.sx);
    }
  }), children));
};

var MRT_TableBodyRowGrabHandle = function MRT_TableBodyRowGrabHandle(_ref) {
  var cell = _ref.cell,
      rowRef = _ref.rowRef,
      table = _ref.table;
  var _table$options = table.options,
      muiTableBodyRowDragHandleProps = _table$options.muiTableBodyRowDragHandleProps,
      onRowDrop = _table$options.onRowDrop;
  var iconButtonProps = muiTableBodyRowDragHandleProps instanceof Function ? muiTableBodyRowDragHandleProps({
    row: cell.row,
    table: table
  }) : muiTableBodyRowDragHandleProps;

  var handleDragStart = function handleDragStart(e) {
    e.dataTransfer.setDragImage(rowRef.current, 0, 0);
    table.setCurrentDraggingRow(cell.row);
  };

  var handleDragEnd = function handleDragEnd(event) {
    onRowDrop == null ? void 0 : onRowDrop({
      event: event,
      draggedRow: table.getState().currentDraggingRow,
      targetRow: table.getState().currentHoveredRow
    });
    table.setCurrentDraggingRow(null);
    table.setCurrentHoveredRow(null);
  };

  return React__default.createElement(MRT_GrabHandleButton, {
    iconButtonProps: iconButtonProps,
    onDragStart: handleDragStart,
    onDragEnd: handleDragEnd,
    table: table
  });
};

var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var _columnDef$Cell, _row$subRows, _columnDef$Cell2, _row$subRows$length, _row$subRows2;

  var cell = _ref.cell,
      enableHover = _ref.enableHover,
      rowIndex = _ref.rowIndex,
      rowRef = _ref.rowRef,
      table = _ref.table;
  var theme = material.useTheme();
  var getState = table.getState,
      _table$options = table.options,
      editingMode = _table$options.editingMode,
      enableClickToCopy = _table$options.enableClickToCopy,
      enableColumnOrdering = _table$options.enableColumnOrdering,
      enableEditing = _table$options.enableEditing,
      enablePagination = _table$options.enablePagination,
      enableRowNumbers = _table$options.enableRowNumbers,
      muiTableBodyCellProps = _table$options.muiTableBodyCellProps,
      muiTableBodyCellSkeletonProps = _table$options.muiTableBodyCellSkeletonProps,
      rowNumberMode = _table$options.rowNumberMode,
      tableId = _table$options.tableId,
      setCurrentEditingCell = table.setCurrentEditingCell,
      setCurrentHoveredColumn = table.setCurrentHoveredColumn;

  var _getState = getState(),
      currentDraggingColumn = _getState.currentDraggingColumn,
      currentEditingCell = _getState.currentEditingCell,
      currentEditingRow = _getState.currentEditingRow,
      currentHoveredColumn = _getState.currentHoveredColumn,
      density = _getState.density,
      isLoading = _getState.isLoading,
      showSkeletons = _getState.showSkeletons;

  var column = cell.column,
      row = cell.row;
  var columnDef = column.columnDef;
  var columnDefType = columnDef.columnDefType;
  var mTableCellBodyProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps({
    cell: cell,
    table: table
  }) : muiTableBodyCellProps;
  var mcTableCellBodyProps = columnDef.muiTableBodyCellProps instanceof Function ? columnDef.muiTableBodyCellProps({
    cell: cell,
    table: table
  }) : columnDef.muiTableBodyCellProps;

  var tableCellProps = _extends({}, mTableCellBodyProps, mcTableCellBodyProps);

  var skeletonWidth = React.useMemo(function () {
    return columnDefType === 'display' ? column.getSize() / 2 : Math.random() * (column.getSize() - column.getSize() / 3) + column.getSize() / 3;
  }, []);
  var isEditable = (enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false;
  var isEditing = isEditable && (editingMode === 'table' || (currentEditingRow == null ? void 0 : currentEditingRow.id) === row.id || (currentEditingCell == null ? void 0 : currentEditingCell.id) === cell.id);

  var handleDoubleClick = function handleDoubleClick(_event) {
    if ((enableEditing || columnDef.enableEditing) && columnDef.enableEditing !== false && editingMode === 'cell') {
      setCurrentEditingCell(cell);
      setTimeout(function () {
        var textField = document.getElementById("mrt-" + tableId + "-edit-cell-text-field-" + cell.id);

        if (textField) {
          textField.focus();
          textField.select();
        }
      }, 200);
    }
  };

  var getIsLastLeftPinnedColumn = function getIsLastLeftPinnedColumn() {
    return column.getIsPinned() === 'left' && table.getLeftLeafHeaders().length - 1 === column.getPinnedIndex();
  };

  var getIsFirstRightPinnedColumn = function getIsFirstRightPinnedColumn() {
    return column.getIsPinned() === 'right' && column.getPinnedIndex() === 0;
  };

  var getTotalRight = function getTotalRight() {
    return (table.getRightLeafHeaders().length - 1 - column.getPinnedIndex()) * 150;
  };

  var handleDragEnter = function handleDragEnter(_e) {
    if (enableColumnOrdering && currentDraggingColumn) {
      setCurrentHoveredColumn(columnDef.enableColumnOrdering !== false ? column : null);
    }
  };

  var draggingBorder = (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id ? "1px dashed " + theme.palette.divider : (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) === column.id ? "2px dashed " + theme.palette.primary.main : undefined;
  var draggingBorders = draggingBorder ? {
    borderLeft: draggingBorder,
    borderRight: draggingBorder,
    borderBottom: row.index === (enablePagination ? table.getRowModel() : table.getPrePaginationRowModel()).rows.length - 1 ? draggingBorder : undefined
  } : undefined;
  return React__default.createElement(material.TableCell, Object.assign({
    onDoubleClick: handleDoubleClick,
    onDragEnter: handleDragEnter
  }, tableCellProps, {
    sx: function sx(theme) {
      var _columnDef$minSize;

      return _extends({
        backgroundColor: column.getIsPinned() ? material.alpha(material.lighten(theme.palette.background["default"], 0.04), 0.95) : undefined,
        boxShadow: getIsLastLeftPinnedColumn() ? "4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : getIsFirstRightPinnedColumn() ? "-4px 0 4px -2px " + material.alpha(theme.palette.common.black, 0.1) : undefined,
        cursor: isEditable && editingMode === 'cell' ? 'pointer' : 'text',
        left: column.getIsPinned() === 'left' ? column.getStart('left') + "px" : undefined,
        opacity: (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id || (currentHoveredColumn == null ? void 0 : currentHoveredColumn.id) === column.id ? 0.5 : 1,
        overflow: 'hidden',
        p: density === 'compact' ? columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : density === 'comfortable' ? columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem' : columnDefType === 'display' ? '1rem 1.25rem' : '1.5rem',
        pl: column.id === 'mrt-row-expand' ? row.depth + (density === 'compact' ? 0.5 : density === 'comfortable' ? 0.75 : 1.25) + "rem" : undefined,
        position: column.getIsPinned() ? 'sticky' : 'relative',
        right: column.getIsPinned() === 'right' ? getTotalRight() + "px" : undefined,
        textOverflow: columnDefType !== 'display' ? 'ellipsis' : undefined,
        transition: 'all 0.2s ease-in-out',
        whiteSpace: density === 'compact' ? 'nowrap' : 'normal',
        zIndex: (currentDraggingColumn == null ? void 0 : currentDraggingColumn.id) === column.id ? 2 : column.getIsPinned() ? 1 : undefined,
        '&:hover': {
          backgroundColor: enableHover && enableEditing && editingMode !== 'row' ? theme.palette.mode === 'dark' ? material.lighten(theme.palette.background["default"], 0.13) + " !important" : material.darken(theme.palette.background["default"], 0.07) + " !important" : undefined
        }
      }, (tableCellProps == null ? void 0 : tableCellProps.sx) instanceof Function ? tableCellProps.sx(theme) : tableCellProps == null ? void 0 : tableCellProps.sx, draggingBorders, {
        maxWidth: "min(" + column.getSize() + "px, fit-content)",
        minWidth: "max(" + column.getSize() + "px, " + ((_columnDef$minSize = columnDef.minSize) != null ? _columnDef$minSize : 30) + "px)",
        width: column.getSize()
      });
    }
  }), React__default.createElement(React__default.Fragment, null, cell.getIsPlaceholder() ? null : isLoading || showSkeletons ? React__default.createElement(material.Skeleton, Object.assign({
    animation: "wave",
    height: 20,
    width: skeletonWidth
  }, muiTableBodyCellSkeletonProps)) : enableRowNumbers && rowNumberMode === 'static' && column.id === 'mrt-row-numbers' ? rowIndex + 1 : column.id === 'mrt-row-drag' ? React__default.createElement(MRT_TableBodyRowGrabHandle, {
    cell: cell,
    rowRef: rowRef,
    table: table
  }) : columnDefType === 'display' ? columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    table: table
  }) : isEditing ? React__default.createElement(MRT_EditCellTextField, {
    cell: cell,
    table: table
  }) : (enableClickToCopy || columnDef.enableClickToCopy) && columnDef.enableClickToCopy !== false ? React__default.createElement(React__default.Fragment, null, React__default.createElement(MRT_CopyButton, {
    cell: cell,
    table: table
  }, React__default.createElement(React__default.Fragment, null, (_columnDef$Cell = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    table: table
  })) != null ? _columnDef$Cell : cell.renderValue())), cell.getIsGrouped() && React__default.createElement(React__default.Fragment, null, " (", (_row$subRows = row.subRows) == null ? void 0 : _row$subRows.length, ")")) : React__default.createElement(React__default.Fragment, null, (_columnDef$Cell2 = columnDef == null ? void 0 : columnDef.Cell == null ? void 0 : columnDef.Cell({
    cell: cell,
    table: table
  })) != null ? _columnDef$Cell2 : cell.renderValue(), cell.getIsGrouped() && React__default.createElement(React__default.Fragment, null, " (", (_row$subRows$length = (_row$subRows2 = row.subRows) == null ? void 0 : _row$subRows2.length) != null ? _row$subRows$length : '', ")"))));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row,
      table = _ref.table;
  var getVisibleLeafColumns = table.getVisibleLeafColumns,
      _table$options = table.options,
      muiTableBodyRowProps = _table$options.muiTableBodyRowProps,
      muiTableDetailPanelProps = _table$options.muiTableDetailPanelProps,
      renderDetailPanel = _table$options.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    table: table
  }) : muiTableBodyRowProps;
  var tableCellProps = muiTableDetailPanelProps instanceof Function ? muiTableDetailPanelProps({
    row: row,
    table: table
  }) : muiTableDetailPanelProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps), React__default.createElement(material.TableCell, Object.assign({
    colSpan: getVisibleLeafColumns().length
  }, tableCellProps, {
    sx: function sx(theme) {
      return _extends({
        borderBottom: !row.getIsExpanded() ? 'none' : undefined,
        pb: row.getIsExpanded() ? '1rem' : 0,
        pt: row.getIsExpanded() ? '1rem' : 0,
        transition: 'all 0.2s ease-in-out',
        width: table.getTotalSize() + "px"
      }, (tableCellProps == null ? void 0 : tableCellProps.sx) instanceof Function ? tableCellProps.sx(theme) : tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), renderDetailPanel && React__default.createElement(material.Collapse, {
    "in": row.getIsExpanded()
  }, renderDetailPanel({
    row: row,
    table: table
  }))));
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var _row$getVisibleCells;

  var row = _ref.row,
      rowIndex = _ref.rowIndex,
      table = _ref.table;
  var theme = material.useTheme();
  var getIsSomeColumnsPinned = table.getIsSomeColumnsPinned,
      getState = table.getState,
      _table$options = table.options,
      enableRowOrdering = _table$options.enableRowOrdering,
      muiTableBodyRowProps = _table$options.muiTableBodyRowProps,
      renderDetailPanel = _table$options.renderDetailPanel,
      setCurrentHoveredRow = table.setCurrentHoveredRow;

  var _getState = getState(),
      currentDraggingRow = _getState.currentDraggingRow,
      currentHoveredRow = _getState.currentHoveredRow;

  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    table: table
  }) : muiTableBodyRowProps;

  var handleDragEnter = function handleDragEnter(_e) {
    if (enableRowOrdering && currentDraggingRow) {
      setCurrentHoveredRow(row);
    }
  };

  var rowRef = React.useRef(null);
  var draggingBorder = (currentDraggingRow == null ? void 0 : currentDraggingRow.id) === row.id ? "1px dashed " + theme.palette.divider : (currentHoveredRow == null ? void 0 : currentHoveredRow.id) === row.id ? "2px dashed " + theme.palette.primary.main : undefined;
  var draggingBorders = draggingBorder ? {
    border: draggingBorder
  } : undefined;
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.TableRow, Object.assign({
    onDragEnter: handleDragEnter,
    hover: true,
    selected: row.getIsSelected(),
    ref: rowRef
  }, tableRowProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: material.lighten(theme.palette.background["default"], 0.06),
        opacity: (currentDraggingRow == null ? void 0 : currentDraggingRow.id) === row.id || (currentHoveredRow == null ? void 0 : currentHoveredRow.id) === row.id ? 0.5 : 1,
        transition: 'all 0.2s ease-in-out',
        '&:hover td': {
          backgroundColor: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false && getIsSomeColumnsPinned() ? theme.palette.mode === 'dark' ? "" + material.lighten(theme.palette.background["default"], 0.12) : "" + material.darken(theme.palette.background["default"], 0.05) : undefined
        }
      }, (tableRowProps == null ? void 0 : tableRowProps.sx) instanceof Function ? tableRowProps.sx(theme) : tableRowProps == null ? void 0 : tableRowProps.sx, draggingBorders);
    }
  }), row == null ? void 0 : (_row$getVisibleCells = row.getVisibleCells()) == null ? void 0 : _row$getVisibleCells.map == null ? void 0 : _row$getVisibleCells.map(function (cell) {
    return React__default.createElement(MRT_TableBodyCell, {
      cell: cell,
      key: cell.id,
      enableHover: (tableRowProps == null ? void 0 : tableRowProps.hover) !== false,
      rowIndex: rowIndex,
      rowRef: rowRef,
      table: table
    });
  })), renderDetailPanel && !row.getIsGrouped() && React__default.createElement(MRT_TableDetailPanel, {
    row: row,
    table: table
  }));
};

var MRT_TableBody = function MRT_TableBody(_ref) {
  var table = _ref.table,
      tableContainerRef = _ref.tableContainerRef;
  var getRowModel = table.getRowModel,
      getPrePaginationRowModel = table.getPrePaginationRowModel,
      getState = table.getState,
      _table$options = table.options,
      enableGlobalFilterRankedResults = _table$options.enableGlobalFilterRankedResults,
      enablePagination = _table$options.enablePagination,
      enableRowVirtualization = _table$options.enableRowVirtualization,
      muiTableBodyProps = _table$options.muiTableBodyProps,
      virtualizerProps = _table$options.virtualizerProps;

  var _getState = getState(),
      density = _getState.density,
      globalFilter = _getState.globalFilter,
      pagination = _getState.pagination,
      sorting = _getState.sorting;

  var tableBodyProps = muiTableBodyProps instanceof Function ? muiTableBodyProps({
    table: table
  }) : muiTableBodyProps;

  var getIsSomeColumnsSorted = function getIsSomeColumnsSorted() {
    return Object.values(sorting).some(Boolean);
  };

  var rows = React.useMemo(function () {
    if (enableGlobalFilterRankedResults && globalFilter && !getIsSomeColumnsSorted()) {
      var rankedRows = getPrePaginationRowModel().rows.sort(function (a, b) {
        return rankGlobalFuzzy(a, b);
      });

      if (enablePagination) {
        return rankedRows.slice(0, pagination.pageSize);
      }

      return rankedRows;
    }

    return enablePagination ? getRowModel().rows : getPrePaginationRowModel().rows;
  }, [enableGlobalFilterRankedResults, enableGlobalFilterRankedResults && globalFilter || !enablePagination ? getPrePaginationRowModel().rows : getRowModel().rows, globalFilter]);
  var rowVirtualizer = enableRowVirtualization ? reactVirtual.useVirtualizer(_extends({
    estimateSize: function estimateSize() {
      return density === 'compact' ? 25 : 50;
    },
    overscan: density === 'compact' ? 30 : 10,
    getScrollElement: function getScrollElement() {
      return tableContainerRef.current;
    },
    count: rows.length
  }, virtualizerProps)) : {};
  var virtualRows = enableRowVirtualization ? rowVirtualizer.getVirtualItems() : [];
  var paddingTop = 0;
  var paddingBottom = 0;

  if (enableRowVirtualization) {
    paddingTop = !!virtualRows.length ? virtualRows[0].start : 0;
    paddingBottom = !!virtualRows.length ? rowVirtualizer.getTotalSize() - virtualRows[virtualRows.length - 1].end : 0;
  }

  return React__default.createElement(material.TableBody, Object.assign({}, tableBodyProps), enableRowVirtualization && paddingTop > 0 && React__default.createElement("tr", null, React__default.createElement("td", {
    style: {
      height: paddingTop + "px"
    }
  })), (enableRowVirtualization ? virtualRows : rows).map(function (rowOrVirtualRow, rowIndex) {
    var row = enableRowVirtualization ? rows[rowOrVirtualRow.index] : rowOrVirtualRow;
    return React__default.createElement(MRT_TableBodyRow, {
      key: row.id,
      row: row,
      rowIndex: enableRowVirtualization ? rowOrVirtualRow.index : rowIndex,
      table: table
    });
  }), enableRowVirtualization && paddingBottom > 0 && React__default.createElement("tr", null, React__default.createElement("td", {
    style: {
      height: paddingBottom + "px"
    }
  })));
};

var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _ref2, _ref3;

  var footer = _ref.footer,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      muiTableFooterCellProps = _table$options.muiTableFooterCellProps,
      enableColumnResizing = _table$options.enableColumnResizing;

  var _getState = getState(),
      density = _getState.density;

  var column = footer.column;
  var columnDef = column.columnDef;
  var columnDefType = columnDef.columnDefType;
  var mTableFooterCellProps = muiTableFooterCellProps instanceof Function ? muiTableFooterCellProps({
    column: column,
    table: table
  }) : muiTableFooterCellProps;
  var mcTableFooterCellProps = columnDef.muiTableFooterCellProps instanceof Function ? columnDef.muiTableFooterCellProps({
    column: column,
    table: table
  }) : columnDef.muiTableFooterCellProps;

  var tableCellProps = _extends({}, mTableFooterCellProps, mcTableFooterCellProps);

  return React__default.createElement(material.TableCell, Object.assign({
    align: columnDefType === 'group' ? 'center' : 'left',
    colSpan: footer.colSpan,
    variant: "head"
  }, tableCellProps, {
    sx: function sx(theme) {
      return _extends({
        backgroundColor: theme.palette.background["default"],
        backgroundImage: "linear-gradient(" + material.alpha(theme.palette.common.white, 0.05) + "," + material.alpha(theme.palette.common.white, 0.05) + ")",
        fontWeight: 'bold',
        maxWidth: column.getSize() + "px",
        minWidth: column.getSize() + "px",
        p: density === 'compact' ? '0.5rem' : density === 'comfortable' ? '1rem' : '1.5rem',
        transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out",
        width: column.getSize(),
        verticalAlign: 'text-top'
      }, (tableCellProps == null ? void 0 : tableCellProps.sx) instanceof Function ? tableCellProps.sx(theme) : tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), React__default.createElement(React__default.Fragment, null, footer.isPlaceholder ? null : (_ref2 = (_ref3 = columnDef.Footer instanceof Function ? columnDef.Footer == null ? void 0 : columnDef.Footer({
    footer: footer,
    table: table
  }) : columnDef.Footer) != null ? _ref3 : columnDef.footer) != null ? _ref2 : null));
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var _footerGroup$headers;

  var footerGroup = _ref.footerGroup,
      table = _ref.table;
  var muiTableFooterRowProps = table.options.muiTableFooterRowProps; // if no content in row, skip row

  if (!((_footerGroup$headers = footerGroup.headers) != null && _footerGroup$headers.some(function (header) {
    return typeof header.column.columnDef.footer === 'string' && !!header.column.columnDef.footer || header.column.columnDef.Footer;
  }))) return null;
  var tableRowProps = muiTableFooterRowProps instanceof Function ? muiTableFooterRowProps({
    footerGroup: footerGroup,
    table: table
  }) : muiTableFooterRowProps;
  return React__default.createElement(material.TableRow, Object.assign({}, tableRowProps), footerGroup.headers.map(function (footer) {
    return React__default.createElement(MRT_TableFooterCell, {
      footer: footer,
      key: footer.id,
      table: table
    });
  }));
};

var MRT_TableFooter = function MRT_TableFooter(_ref) {
  var table = _ref.table;
  var getFooterGroups = table.getFooterGroups,
      muiTableFooterProps = table.options.muiTableFooterProps;
  var tableFooterProps = muiTableFooterProps instanceof Function ? muiTableFooterProps({
    table: table
  }) : muiTableFooterProps;
  return React__default.createElement(material.TableFooter, Object.assign({}, tableFooterProps), getFooterGroups().map(function (footerGroup) {
    return React__default.createElement(MRT_TableFooterRow, {
      footerGroup: footerGroup,
      key: footerGroup.id,
      table: table
    });
  }));
};

var MRT_Table = function MRT_Table(_ref) {
  var tableContainerRef = _ref.tableContainerRef,
      table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableColumnResizing = _table$options.enableColumnResizing,
      enableRowVirtualization = _table$options.enableRowVirtualization,
      enableStickyHeader = _table$options.enableStickyHeader,
      enableTableFooter = _table$options.enableTableFooter,
      enableTableHead = _table$options.enableTableHead,
      muiTableProps = _table$options.muiTableProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var tableProps = muiTableProps instanceof Function ? muiTableProps({
    table: table
  }) : muiTableProps;
  return React__default.createElement(material.Table, Object.assign({
    stickyHeader: enableStickyHeader || enableRowVirtualization || isFullScreen
  }, tableProps, {
    sx: function sx(theme) {
      return _extends({
        tableLayout: enableColumnResizing || enableRowVirtualization ? 'fixed' : 'auto'
      }, (tableProps == null ? void 0 : tableProps.sx) instanceof Function ? tableProps.sx(theme) : tableProps == null ? void 0 : tableProps.sx);
    }
  }), enableTableHead && React__default.createElement(MRT_TableHead, {
    table: table
  }), React__default.createElement(MRT_TableBody, {
    tableContainerRef: tableContainerRef,
    table: table
  }), enableTableFooter && React__default.createElement(MRT_TableFooter, {
    table: table
  }));
};

var useIsomorphicLayoutEffect = typeof window !== 'undefined' ? React.useLayoutEffect : React.useEffect;
var MRT_TableContainer = function MRT_TableContainer(_ref) {
  var table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableStickyHeader = _table$options.enableStickyHeader,
      enableRowVirtualization = _table$options.enableRowVirtualization,
      muiTableContainerProps = _table$options.muiTableContainerProps,
      tableId = _table$options.tableId;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var _useState = React.useState(0),
      totalToolbarHeight = _useState[0],
      setTotalToolbarHeight = _useState[1];

  var tableContainerProps = muiTableContainerProps instanceof Function ? muiTableContainerProps({
    table: table
  }) : muiTableContainerProps;
  useIsomorphicLayoutEffect(function () {
    var _document$getElementB, _document, _document$getElementB2, _document$getElementB3, _document2, _document2$getElement;

    var topToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB = (_document = document) == null ? void 0 : (_document$getElementB2 = _document.getElementById("mrt-" + tableId + "-toolbar-top")) == null ? void 0 : _document$getElementB2.offsetHeight) != null ? _document$getElementB : 0 : 0;
    var bottomToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB3 = (_document2 = document) == null ? void 0 : (_document2$getElement = _document2.getElementById("mrt-" + tableId + "-toolbar-bottom")) == null ? void 0 : _document2$getElement.offsetHeight) != null ? _document$getElementB3 : 0 : 0;
    setTotalToolbarHeight(topToolbarHeight + bottomToolbarHeight);
  });
  var tableContainerRef = React__default.useRef(null);
  return React__default.createElement(material.TableContainer, Object.assign({
    ref: tableContainerRef
  }, tableContainerProps, {
    sx: function sx(theme) {
      return _extends({
        maxWidth: '100%',
        maxHeight: enableStickyHeader || enableRowVirtualization ? "clamp(350px, calc(100vh - " + totalToolbarHeight + "px), 9999px)" : undefined,
        overflow: 'auto'
      }, (tableContainerProps == null ? void 0 : tableContainerProps.sx) instanceof Function ? tableContainerProps.sx(theme) : tableContainerProps == null ? void 0 : tableContainerProps.sx);
    },
    style: _extends({
      maxHeight: isFullScreen ? "calc(100vh - " + totalToolbarHeight + "px)" : undefined
    }, tableContainerProps == null ? void 0 : tableContainerProps.style)
  }), React__default.createElement(MRT_Table, {
    tableContainerRef: tableContainerRef,
    table: table
  }));
};

var MRT_TablePaper = function MRT_TablePaper(_ref) {
  var table = _ref.table;
  var getState = table.getState,
      _table$options = table.options,
      enableToolbarBottom = _table$options.enableToolbarBottom,
      enableToolbarTop = _table$options.enableToolbarTop,
      muiTablePaperProps = _table$options.muiTablePaperProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  React.useEffect(function () {
    if (typeof window !== 'undefined') {
      if (isFullScreen) {
        document.body.style.height = '100vh';
      } else {
        document.body.style.height = 'auto';
      }
    }
  }, [isFullScreen]);
  var tablePaperProps = muiTablePaperProps instanceof Function ? muiTablePaperProps({
    table: table
  }) : muiTablePaperProps;
  return React__default.createElement(material.Paper, Object.assign({
    elevation: 2
  }, tablePaperProps, {
    sx: _extends({
      transition: 'all 0.2s ease-in-out'
    }, tablePaperProps == null ? void 0 : tablePaperProps.sx),
    style: _extends({}, tablePaperProps == null ? void 0 : tablePaperProps.style, {
      height: isFullScreen ? '100vh' : undefined,
      margin: isFullScreen ? '0' : undefined,
      maxHeight: isFullScreen ? '100vh' : undefined,
      maxWidth: isFullScreen ? '100vw' : undefined,
      padding: isFullScreen ? '0' : undefined,
      width: isFullScreen ? '100vw' : undefined
    })
  }), enableToolbarTop && React__default.createElement(MRT_ToolbarTop, {
    table: table
  }), React__default.createElement(MRT_TableContainer, {
    table: table
  }), enableToolbarBottom && React__default.createElement(MRT_ToolbarBottom, {
    table: table
  }));
};

var defaultDisplayColumnDefOptions = {
  columnDefType: 'display',
  enableClickToCopy: false,
  enableColumnActions: false,
  enableColumnDragging: false,
  enableColumnFilter: false,
  enableColumnOrdering: false,
  enableEditing: false,
  enableGlobalFilter: false,
  enableGrouping: false,
  enableHiding: false,
  enablePinning: false,
  enableResizing: false,
  enableSorting: false
};
var MRT_TableRoot = function MRT_TableRoot(props) {
  var _initialState$columnO, _initialState$current, _initialState$current2, _initialState$current3, _initialState$current4, _initialState$current5, _initialState$current6, _initialState$density, _initialState$isFullS, _props$initialState$s, _props$initialState2, _initialState$showCol, _initialState$showGlo, _props$state3, _props$state4, _MRT_FilterFns$curren, _props$onCurrentDragg, _props$onCurrentDragg2, _props$onCurrentEditi, _props$onCurrentEditi2, _props$onCurrentFilte, _props$onCurrentGloba, _props$onCurrentHover, _props$onCurrentHover2, _props$onDensityChang, _props$onIsFullScreen, _props$onShowAlertBan, _props$onShowFiltersC, _props$onShowGlobalFi;

  var _useState = React.useState(props.tableId),
      tableId = _useState[0],
      setIdPrefix = _useState[1];

  React.useEffect(function () {
    var _props$tableId;

    return setIdPrefix((_props$tableId = props.tableId) != null ? _props$tableId : Math.random().toString(36).substring(2, 9));
  }, [props.tableId]);
  var initialState = React.useMemo(function () {
    var _props$initialState, _initState$columnOrde;

    var initState = (_props$initialState = props.initialState) != null ? _props$initialState : {};
    initState.columnOrder = (_initState$columnOrde = initState.columnOrder) != null ? _initState$columnOrde : getDefaultColumnOrderIds(props);
    return initState;
  }, []);

  var _useState2 = React.useState((_initialState$columnO = initialState.columnOrder) != null ? _initialState$columnO : []),
      columnOrder = _useState2[0],
      setColumnOrder = _useState2[1];

  var _useState3 = React.useState((_initialState$current = initialState.currentDraggingColumn) != null ? _initialState$current : null),
      currentDraggingColumn = _useState3[0],
      setCurrentDraggingColumn = _useState3[1];

  var _useState4 = React.useState((_initialState$current2 = initialState.currentDraggingRow) != null ? _initialState$current2 : null),
      currentDraggingRow = _useState4[0],
      setCurrentDraggingRow = _useState4[1];

  var _useState5 = React.useState((_initialState$current3 = initialState.currentEditingCell) != null ? _initialState$current3 : null),
      currentEditingCell = _useState5[0],
      setCurrentEditingCell = _useState5[1];

  var _useState6 = React.useState((_initialState$current4 = initialState.currentEditingRow) != null ? _initialState$current4 : null),
      currentEditingRow = _useState6[0],
      setCurrentEditingRow = _useState6[1];

  var _useState7 = React.useState((_initialState$current5 = initialState.currentHoveredColumn) != null ? _initialState$current5 : null),
      currentHoveredColumn = _useState7[0],
      setCurrentHoveredColumn = _useState7[1];

  var _useState8 = React.useState((_initialState$current6 = initialState.currentHoveredRow) != null ? _initialState$current6 : null),
      currentHoveredRow = _useState8[0],
      setCurrentHoveredRow = _useState8[1];

  var _useState9 = React.useState((_initialState$density = initialState == null ? void 0 : initialState.density) != null ? _initialState$density : 'comfortable'),
      density = _useState9[0],
      setDensity = _useState9[1];

  var _useState10 = React.useState((_initialState$isFullS = initialState == null ? void 0 : initialState.isFullScreen) != null ? _initialState$isFullS : false),
      isFullScreen = _useState10[0],
      setIsFullScreen = _useState10[1];

  var _useState11 = React.useState((_props$initialState$s = (_props$initialState2 = props.initialState) == null ? void 0 : _props$initialState2.showAlertBanner) != null ? _props$initialState$s : false),
      showAlertBanner = _useState11[0],
      setShowAlertBanner = _useState11[1];

  var _useState12 = React.useState((_initialState$showCol = initialState == null ? void 0 : initialState.showColumnFilters) != null ? _initialState$showCol : false),
      showColumnFilters = _useState12[0],
      setShowFilters = _useState12[1];

  var _useState13 = React.useState((_initialState$showGlo = initialState == null ? void 0 : initialState.showGlobalFilter) != null ? _initialState$showGlo : false),
      showGlobalFilter = _useState13[0],
      setShowGlobalFilter = _useState13[1];

  var _useState14 = React.useState(function () {
    return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (col) {
      var _ref, _col$id$toString, _col$id, _col$accessorKey, _col$filterFn$name, _ref2, _col$filterFn, _initialState$current7, _ref3, _col$id$toString2, _col$id2, _col$accessorKey2, _ref4;

      return _ref4 = {}, _ref4[(_ref = (_col$id$toString = (_col$id = col.id) == null ? void 0 : _col$id.toString()) != null ? _col$id$toString : (_col$accessorKey = col.accessorKey) == null ? void 0 : _col$accessorKey.toString()) != null ? _ref : ''] = col.filterFn instanceof Function ? (_col$filterFn$name = col.filterFn.name) != null ? _col$filterFn$name : 'custom' : (_ref2 = (_col$filterFn = col.filterFn) != null ? _col$filterFn : initialState == null ? void 0 : (_initialState$current7 = initialState.currentFilterFns) == null ? void 0 : _initialState$current7[(_ref3 = (_col$id$toString2 = (_col$id2 = col.id) == null ? void 0 : _col$id2.toString()) != null ? _col$id$toString2 : (_col$accessorKey2 = col.accessorKey) == null ? void 0 : _col$accessorKey2.toString()) != null ? _ref3 : '']) != null ? _ref2 : getDefaultColumnFilterFn(col), _ref4;
    })));
  }),
      currentFilterFns = _useState14[0],
      setCurrentFilterFns = _useState14[1];

  var _useState15 = React.useState(props.globalFilterFn instanceof String ? props.globalFilterFn : 'fuzzy'),
      currentGlobalFilterFn = _useState15[0],
      setCurrentGlobalFilterFn = _useState15[1];

  var displayColumns = React.useMemo(function () {
    var _props$localization, _props$displayColumnD, _props$localization2, _props$displayColumnD2, _props$localization3, _props$displayColumnD3, _props$localization4, _props$displayColumnD4, _props$localization6, _props$displayColumnD5;

    return [columnOrder.includes('mrt-row-drag') && _extends({
      header: (_props$localization = props.localization) == null ? void 0 : _props$localization.move,
      size: 60
    }, defaultDisplayColumnDefOptions, (_props$displayColumnD = props.displayColumnDefOptions) == null ? void 0 : _props$displayColumnD['mrt-row-drag'], {
      id: 'mrt-row-drag'
    }), columnOrder.includes('mrt-row-actions') && _extends({
      Cell: function Cell(_ref5) {
        var cell = _ref5.cell;
        return React__default.createElement(MRT_ToggleRowActionMenuButton, {
          row: cell.row,
          table: table
        });
      },
      header: (_props$localization2 = props.localization) == null ? void 0 : _props$localization2.actions,
      size: 70
    }, defaultDisplayColumnDefOptions, (_props$displayColumnD2 = props.displayColumnDefOptions) == null ? void 0 : _props$displayColumnD2['mrt-row-actions'], {
      id: 'mrt-row-actions'
    }), columnOrder.includes('mrt-row-expand') && _extends({
      Cell: function Cell(_ref6) {
        var cell = _ref6.cell;
        return React__default.createElement(MRT_ExpandButton, {
          row: cell.row,
          table: table
        });
      },
      Header: function Header() {
        return props.enableExpandAll ? React__default.createElement(MRT_ExpandAllButton, {
          table: table
        }) : null;
      },
      header: (_props$localization3 = props.localization) == null ? void 0 : _props$localization3.expand,
      size: 60
    }, defaultDisplayColumnDefOptions, (_props$displayColumnD3 = props.displayColumnDefOptions) == null ? void 0 : _props$displayColumnD3['mrt-row-expand'], {
      id: 'mrt-row-expand'
    }), columnOrder.includes('mrt-row-select') && _extends({
      Cell: function Cell(_ref7) {
        var cell = _ref7.cell;
        return React__default.createElement(MRT_SelectCheckbox, {
          row: cell.row,
          table: table
        });
      },
      Header: function Header() {
        return props.enableSelectAll ? React__default.createElement(MRT_SelectCheckbox, {
          selectAll: true,
          table: table
        }) : null;
      },
      header: (_props$localization4 = props.localization) == null ? void 0 : _props$localization4.select,
      size: 60
    }, defaultDisplayColumnDefOptions, (_props$displayColumnD4 = props.displayColumnDefOptions) == null ? void 0 : _props$displayColumnD4['mrt-row-select'], {
      id: 'mrt-row-select'
    }), columnOrder.includes('mrt-row-numbers') && _extends({
      Cell: function Cell(_ref8) {
        var cell = _ref8.cell;
        return cell.row.index + 1;
      },
      Header: function Header() {
        var _props$localization5;

        return (_props$localization5 = props.localization) == null ? void 0 : _props$localization5.rowNumber;
      },
      header: (_props$localization6 = props.localization) == null ? void 0 : _props$localization6.rowNumbers,
      size: 60
    }, defaultDisplayColumnDefOptions, (_props$displayColumnD5 = props.displayColumnDefOptions) == null ? void 0 : _props$displayColumnD5['mrt-row-numbers'], {
      id: 'mrt-row-numbers'
    })].filter(Boolean);
  }, [columnOrder, props.displayColumnDefOptions, props.editingMode, props.enableColumnDragging, props.enableColumnOrdering, props.enableEditing, props.enableExpandAll, props.enableExpanding, props.enableGrouping, props.enableRowActions, props.enableRowDragging, props.enableRowNumbers, props.enableRowOrdering, props.enableRowSelection, props.enableSelectAll, props.localization, props.muiTableBodyCellProps, props.muiTableHeadCellProps, props.positionActionsColumn]);
  var columnDefs = React.useMemo(function () {
    return prepareColumns([].concat(displayColumns, props.columns), currentFilterFns);
  }, [currentFilterFns, displayColumns, props.columns]);
  var data = React.useMemo(function () {
    var _props$state, _props$state2;

    return ((_props$state = props.state) != null && _props$state.isLoading || (_props$state2 = props.state) != null && _props$state2.showSkeletons) && !props.data.length ? [].concat(Array(10).fill(null)).map(function () {
      return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (col) {
        var _ref9, _col$id3, _ref10;

        return _ref10 = {}, _ref10[(_ref9 = (_col$id3 = col.id) != null ? _col$id3 : col.accessorKey) != null ? _ref9 : ''] = null, _ref10;
      })));
    }) : props.data;
  }, [props.data, (_props$state3 = props.state) == null ? void 0 : _props$state3.isLoading, (_props$state4 = props.state) == null ? void 0 : _props$state4.showSkeletons]); //@ts-ignore

  var table = _extends({}, reactTable.useReactTable(_extends({
    getCoreRowModel: reactTable.getCoreRowModel(),
    getExpandedRowModel: reactTable.getExpandedRowModel(),
    getFacetedRowModel: reactTable.getFacetedRowModel(),
    getFilteredRowModel: reactTable.getFilteredRowModel(),
    getGroupedRowModel: reactTable.getGroupedRowModel(),
    getPaginationRowModel: reactTable.getPaginationRowModel(),
    getSortedRowModel: reactTable.getSortedRowModel(),
    onColumnOrderChange: setColumnOrder
  }, props, {
    //@ts-ignore
    columns: columnDefs,
    data: data,
    getSubRows: function getSubRows(row) {
      return row == null ? void 0 : row.subRows;
    },
    globalFilterFn: (_MRT_FilterFns$curren = MRT_FilterFns[currentGlobalFilterFn]) != null ? _MRT_FilterFns$curren : MRT_FilterFns.fuzzy,
    initialState: initialState,
    state: _extends({
      columnOrder: columnOrder,
      currentDraggingColumn: currentDraggingColumn,
      currentDraggingRow: currentDraggingRow,
      currentEditingCell: currentEditingCell,
      currentEditingRow: currentEditingRow,
      currentFilterFns: currentFilterFns,
      currentGlobalFilterFn: currentGlobalFilterFn,
      currentHoveredColumn: currentHoveredColumn,
      currentHoveredRow: currentHoveredRow,
      density: density,
      isFullScreen: isFullScreen,
      showAlertBanner: showAlertBanner,
      showColumnFilters: showColumnFilters,
      showGlobalFilter: showGlobalFilter
    }, props.state),
    tableId: tableId
  })), {
    setCurrentDraggingColumn: (_props$onCurrentDragg = props.onCurrentDraggingColumnChange) != null ? _props$onCurrentDragg : setCurrentDraggingColumn,
    setCurrentDraggingRow: (_props$onCurrentDragg2 = props.onCurrentDraggingRowChange) != null ? _props$onCurrentDragg2 : setCurrentDraggingRow,
    setCurrentEditingCell: (_props$onCurrentEditi = props.onCurrentEditingCellChange) != null ? _props$onCurrentEditi : setCurrentEditingCell,
    setCurrentEditingRow: (_props$onCurrentEditi2 = props.onCurrentEditingRowChange) != null ? _props$onCurrentEditi2 : setCurrentEditingRow,
    setCurrentFilterFns: (_props$onCurrentFilte = props.onCurrentFilterFnsChange) != null ? _props$onCurrentFilte : setCurrentFilterFns,
    setCurrentGlobalFilterFn: (_props$onCurrentGloba = props.onCurrentGlobalFilterFnChange) != null ? _props$onCurrentGloba : setCurrentGlobalFilterFn,
    setCurrentHoveredColumn: (_props$onCurrentHover = props.onCurrentHoveredColumnChange) != null ? _props$onCurrentHover : setCurrentHoveredColumn,
    setCurrentHoveredRow: (_props$onCurrentHover2 = props.onCurrentHoveredRowChange) != null ? _props$onCurrentHover2 : setCurrentHoveredRow,
    setDensity: (_props$onDensityChang = props.onDensityChange) != null ? _props$onDensityChang : setDensity,
    setIsFullScreen: (_props$onIsFullScreen = props.onIsFullScreenChange) != null ? _props$onIsFullScreen : setIsFullScreen,
    setShowAlertBanner: (_props$onShowAlertBan = props.onShowAlertBannerChange) != null ? _props$onShowAlertBan : setShowAlertBanner,
    setShowFilters: (_props$onShowFiltersC = props.onShowFiltersChange) != null ? _props$onShowFiltersC : setShowFilters,
    setShowGlobalFilter: (_props$onShowGlobalFi = props.onShowGlobalFilterChange) != null ? _props$onShowGlobalFi : setShowGlobalFilter
  });

  React.useEffect(function () {
    return props == null ? void 0 : props.onTableInstanceChange == null ? void 0 : props.onTableInstanceChange(table);
  }, [table]);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.Dialog, {
    PaperComponent: material.Box,
    TransitionComponent: material.Grow,
    disablePortal: true,
    fullScreen: true,
    keepMounted: false,
    onClose: function onClose() {
      return setIsFullScreen(false);
    },
    open: isFullScreen,
    transitionDuration: 400
  }, React__default.createElement(MRT_TablePaper, {
    table: table
  })), !isFullScreen && React__default.createElement(MRT_TablePaper, {
    table: table
  }));
};

var _excluded$5 = ["autoResetExpanded", "columnResizeMode", "defaultColumn", "editingMode", "enableColumnActions", "enableColumnFilterChangeMode", "enableColumnFilters", "enableColumnOrdering", "enableColumnResizing", "enableDensityToggle", "enableExpandAll", "enableFilters", "enableFullScreenToggle", "enableGlobalFilter", "enableGlobalFilterChangeMode", "enableGlobalFilterRankedResults", "enableGrouping", "enableHiding", "enableMultiRowSelection", "enableMultiSort", "enablePagination", "enablePinning", "enableRowSelection", "enableSelectAll", "enableSorting", "enableStickyHeader", "enableTableFooter", "enableTableHead", "enableToolbarBottom", "enableToolbarInternalActions", "enableToolbarTop", "icons", "localization", "positionActionsColumn", "positionExpandColumn", "positionGlobalFilter", "positionPagination", "positionToolbarAlertBanner", "rowNumberMode", "selectAllMode"];
var MaterialReactTable = (function (_ref) {
  var _ref$autoResetExpande = _ref.autoResetExpanded,
      autoResetExpanded = _ref$autoResetExpande === void 0 ? false : _ref$autoResetExpande,
      _ref$columnResizeMode = _ref.columnResizeMode,
      columnResizeMode = _ref$columnResizeMode === void 0 ? 'onEnd' : _ref$columnResizeMode,
      _ref$defaultColumn = _ref.defaultColumn,
      defaultColumn = _ref$defaultColumn === void 0 ? {
    minSize: 40,
    maxSize: 1000,
    size: 180
  } : _ref$defaultColumn,
      _ref$editingMode = _ref.editingMode,
      editingMode = _ref$editingMode === void 0 ? 'row' : _ref$editingMode,
      _ref$enableColumnActi = _ref.enableColumnActions,
      enableColumnActions = _ref$enableColumnActi === void 0 ? true : _ref$enableColumnActi,
      _ref$enableColumnFilt = _ref.enableColumnFilterChangeMode,
      enableColumnFilterChangeMode = _ref$enableColumnFilt === void 0 ? false : _ref$enableColumnFilt,
      _ref$enableColumnFilt2 = _ref.enableColumnFilters,
      enableColumnFilters = _ref$enableColumnFilt2 === void 0 ? true : _ref$enableColumnFilt2,
      _ref$enableColumnOrde = _ref.enableColumnOrdering,
      enableColumnOrdering = _ref$enableColumnOrde === void 0 ? false : _ref$enableColumnOrde,
      _ref$enableColumnResi = _ref.enableColumnResizing,
      enableColumnResizing = _ref$enableColumnResi === void 0 ? false : _ref$enableColumnResi,
      _ref$enableDensityTog = _ref.enableDensityToggle,
      enableDensityToggle = _ref$enableDensityTog === void 0 ? true : _ref$enableDensityTog,
      _ref$enableExpandAll = _ref.enableExpandAll,
      enableExpandAll = _ref$enableExpandAll === void 0 ? true : _ref$enableExpandAll,
      _ref$enableFilters = _ref.enableFilters,
      enableFilters = _ref$enableFilters === void 0 ? true : _ref$enableFilters,
      _ref$enableFullScreen = _ref.enableFullScreenToggle,
      enableFullScreenToggle = _ref$enableFullScreen === void 0 ? true : _ref$enableFullScreen,
      _ref$enableGlobalFilt = _ref.enableGlobalFilter,
      enableGlobalFilter = _ref$enableGlobalFilt === void 0 ? true : _ref$enableGlobalFilt,
      _ref$enableGlobalFilt2 = _ref.enableGlobalFilterChangeMode,
      enableGlobalFilterChangeMode = _ref$enableGlobalFilt2 === void 0 ? false : _ref$enableGlobalFilt2,
      _ref$enableGlobalFilt3 = _ref.enableGlobalFilterRankedResults,
      enableGlobalFilterRankedResults = _ref$enableGlobalFilt3 === void 0 ? true : _ref$enableGlobalFilt3,
      _ref$enableGrouping = _ref.enableGrouping,
      enableGrouping = _ref$enableGrouping === void 0 ? false : _ref$enableGrouping,
      _ref$enableHiding = _ref.enableHiding,
      enableHiding = _ref$enableHiding === void 0 ? true : _ref$enableHiding,
      _ref$enableMultiRowSe = _ref.enableMultiRowSelection,
      enableMultiRowSelection = _ref$enableMultiRowSe === void 0 ? true : _ref$enableMultiRowSe,
      _ref$enableMultiSort = _ref.enableMultiSort,
      enableMultiSort = _ref$enableMultiSort === void 0 ? true : _ref$enableMultiSort,
      _ref$enablePagination = _ref.enablePagination,
      enablePagination = _ref$enablePagination === void 0 ? true : _ref$enablePagination,
      _ref$enablePinning = _ref.enablePinning,
      enablePinning = _ref$enablePinning === void 0 ? false : _ref$enablePinning,
      _ref$enableRowSelecti = _ref.enableRowSelection,
      enableRowSelection = _ref$enableRowSelecti === void 0 ? false : _ref$enableRowSelecti,
      _ref$enableSelectAll = _ref.enableSelectAll,
      enableSelectAll = _ref$enableSelectAll === void 0 ? true : _ref$enableSelectAll,
      _ref$enableSorting = _ref.enableSorting,
      enableSorting = _ref$enableSorting === void 0 ? true : _ref$enableSorting,
      _ref$enableStickyHead = _ref.enableStickyHeader,
      enableStickyHeader = _ref$enableStickyHead === void 0 ? false : _ref$enableStickyHead,
      _ref$enableTableFoote = _ref.enableTableFooter,
      enableTableFooter = _ref$enableTableFoote === void 0 ? true : _ref$enableTableFoote,
      _ref$enableTableHead = _ref.enableTableHead,
      enableTableHead = _ref$enableTableHead === void 0 ? true : _ref$enableTableHead,
      _ref$enableToolbarBot = _ref.enableToolbarBottom,
      enableToolbarBottom = _ref$enableToolbarBot === void 0 ? true : _ref$enableToolbarBot,
      _ref$enableToolbarInt = _ref.enableToolbarInternalActions,
      enableToolbarInternalActions = _ref$enableToolbarInt === void 0 ? true : _ref$enableToolbarInt,
      _ref$enableToolbarTop = _ref.enableToolbarTop,
      enableToolbarTop = _ref$enableToolbarTop === void 0 ? true : _ref$enableToolbarTop,
      icons = _ref.icons,
      localization = _ref.localization,
      _ref$positionActionsC = _ref.positionActionsColumn,
      positionActionsColumn = _ref$positionActionsC === void 0 ? 'first' : _ref$positionActionsC,
      _ref$positionExpandCo = _ref.positionExpandColumn,
      positionExpandColumn = _ref$positionExpandCo === void 0 ? 'first' : _ref$positionExpandCo,
      _ref$positionGlobalFi = _ref.positionGlobalFilter,
      positionGlobalFilter = _ref$positionGlobalFi === void 0 ? 'right' : _ref$positionGlobalFi,
      _ref$positionPaginati = _ref.positionPagination,
      positionPagination = _ref$positionPaginati === void 0 ? 'bottom' : _ref$positionPaginati,
      _ref$positionToolbarA = _ref.positionToolbarAlertBanner,
      positionToolbarAlertBanner = _ref$positionToolbarA === void 0 ? 'top' : _ref$positionToolbarA,
      _ref$rowNumberMode = _ref.rowNumberMode,
      rowNumberMode = _ref$rowNumberMode === void 0 ? 'original' : _ref$rowNumberMode,
      _ref$selectAllMode = _ref.selectAllMode,
      selectAllMode = _ref$selectAllMode === void 0 ? 'all' : _ref$selectAllMode,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$5);

  return React__default.createElement(MRT_TableRoot, Object.assign({
    autoResetExpanded: autoResetExpanded,
    columnResizeMode: columnResizeMode,
    defaultColumn: defaultColumn,
    editingMode: editingMode,
    enableColumnActions: enableColumnActions,
    enableColumnFilterChangeMode: enableColumnFilterChangeMode,
    enableColumnFilters: enableColumnFilters,
    enableColumnOrdering: enableColumnOrdering,
    enableColumnResizing: enableColumnResizing,
    enableDensityToggle: enableDensityToggle,
    enableExpandAll: enableExpandAll,
    enableFilters: enableFilters,
    enableFullScreenToggle: enableFullScreenToggle,
    enableGlobalFilter: enableGlobalFilter,
    enableGlobalFilterChangeMode: enableGlobalFilterChangeMode,
    enableGlobalFilterRankedResults: enableGlobalFilterRankedResults,
    enableGrouping: enableGrouping,
    enableHiding: enableHiding,
    enableMultiRowSelection: enableMultiRowSelection,
    enableMultiSort: enableMultiSort,
    enablePagination: enablePagination,
    enablePinning: enablePinning,
    enableRowSelection: enableRowSelection,
    enableSelectAll: enableSelectAll,
    enableSorting: enableSorting,
    enableStickyHeader: enableStickyHeader,
    enableTableFooter: enableTableFooter,
    enableTableHead: enableTableHead,
    enableToolbarBottom: enableToolbarBottom,
    enableToolbarInternalActions: enableToolbarInternalActions,
    enableToolbarTop: enableToolbarTop,
    icons: _extends({}, MRT_Default_Icons, icons),
    localization: _extends({}, MRT_DefaultLocalization_EN, localization),
    positionActionsColumn: positionActionsColumn,
    positionExpandColumn: positionExpandColumn,
    positionGlobalFilter: positionGlobalFilter,
    positionPagination: positionPagination,
    positionToolbarAlertBanner: positionToolbarAlertBanner,
    rowNumberMode: rowNumberMode,
    selectAllMode: selectAllMode
  }, rest));
});

exports.default = MaterialReactTable;
//# sourceMappingURL=material-react-table.cjs.development.js.map
